@@ -1,4 +1,15 @@
-/* Allan CORNET INRIA 2005 */
+/*
+ * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Copyright (C) INRIA - 2005 - Allan CORNET
+ * 
+ * This file must be used under the terms of the CeCILL.
+ * This source file is licensed as described in the file COPYING, which
+ * you should have received as part of this distribution.  The terms
+ * are also available at    
+ * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
+ *
+ */
+ 
 
 #ifndef __SCI_MEM_ALLOC__
 #define __SCI_MEM_ALLOC__
@@ -74,20 +85,18 @@
  * Unix/Linux only
  *
  * @param lpAddress Address 
- * @param file Which file is calling the function (used debug) 
- * @param line Which line is calling the function (used debug) 
  * @return <ReturnValue>
  */
- void MyFree(void *lpAddress,const char *file,int line);
+void MyFree(void *lpAddress);
 
 #define MALLOC(x) MyAlloc((size_t)x,__FILE__,__LINE__)
-#define FREE(x) MyFree((void *) x,__FILE__,__LINE__)
+#define FREE(x) MyFree((void *) x)
 #define REALLOC(x,y) MyReAlloc((void *)x, y,__FILE__,__LINE__)
 #define CALLOC(x,y) MyCalloc((size_t) x, (size_t) y,__FILE__,__LINE__)
 
 /* Only for Scilab Stacksize use VirtualAlloc on Window */
 #define SCISTACKMALLOC(x) MyAlloc((unsigned long)x,__FILE__,__LINE__)
-#define SCISTACKFREE(x) MyFree((void *) x,__FILE__,__LINE__)
+#define SCISTACKFREE(x) MyFree((void *) x)
 
 #define Top C2F(vstk).top
 
