@@ -12,7 +12,7 @@
 
 #include <signal.h> /* for SIGINT */
 #include "InterpreterManagement.h"
-#include "dynamic_menus.h"
+#include "storeCommand.h"
 #include "sigbas.h"
 /*--------------------------------------------------------------------------*/
 int putCommandInScilabQueue(char *command)
