@@ -13,6 +13,6 @@
 #define __INTERNAL_STRING_API__
 
 //local string functions
-SciErr fillMatrixOfString(void* _pvCtx, int* _piAddress, int _iRows, int _iCols, char** _pstStrings, int* _piTotalLen);
+SciErr fillMatrixOfString(void* _pvCtx, int* _piAddress, int _iRows, int _iCols, const char* const* _pstStrings, int* _piTotalLen);
 
 #endif /* __INTERNAL_STRING_API__ */
