@@ -18,20 +18,21 @@
 #include "stack-c.h"
 #include "callFunctionFromGateway.h"
 /*--------------------------------------------------------------------------*/
-static gw_generic_table Tab[]={
-  {C2F(intdsaupd),"dsaupd"},
-  {C2F(intdnaupd),"dnaupd"},
-  {C2F(intznaupd),"znaupd"},
-  {C2F(intdseupd),"dseupd"},
-  {C2F(intdneupd),"dneupd"},
-  {C2F(intzneupd),"zneupd"},
+static gw_generic_table Tab[] = 
+{
+  {sci_dsaupd,"dsaupd"},
+  {sci_dnaupd,"dnaupd"},
+  {sci_znaupd,"znaupd"},
+  {sci_dseupd,"dseupd"},
+  {sci_dneupd,"dneupd"},
+  {sci_zneupd,"zneupd"}
 };
 /*--------------------------------------------------------------------------*/
 int gw_arnoldi(void)
 {
 	Rhs = Max(0, Rhs);
 
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 
 	return 0;
 }
