@@ -15,7 +15,7 @@
 #include "gw_boolean.h"
 #include "callFunctionFromGateway.h"
 /*--------------------------------------------------------------------------*/
-static gw_generic_table Tab[]=
+static gw_generic_table Tab[] =
 {
 	{C2F(sci_find),"find"},
 	{C2F(sci_bool2s),"bool2s"},
@@ -25,7 +25,7 @@ static gw_generic_table Tab[]=
 /*--------------------------------------------------------------------------*/
 int gw_boolean(void)
 {  
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 	return 0;
 }
 /*--------------------------------------------------------------------------*/
