@@ -2,6 +2,7 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) INRIA - Allan CORNET
+ * Copyright (C) DIGITEO - 2010 - Allan CORNET
  * 
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
@@ -18,15 +19,15 @@
 /*--------------------------------------------------------------------------*/
 static gw_generic_table Tab[] =
 {
-	{C2F(sci_arl2),"arl2_ius"},
-	{C2F(sci_residu),"residu"},
-	{C2F(sci_ldiv),"ldiv"}
+    {sci_arl2, "arl2_ius"},
+    {sci_residu, "residu"},
+    {sci_ldiv, "ldiv"}
 };
 /*--------------------------------------------------------------------------*/
 int gw_cacsd3(void)
 {  
-	if ( Fin-1 > 2) return 0;
-	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
-	return 0;
+    if ( Fin-1 > 2) return 0;
+    callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
+    return 0;
 }
 /*--------------------------------------------------------------------------*/
