@@ -16,7 +16,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intereduc)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_ereduc)(char *fname,unsigned long fname_len)
+int sci_ereduc(char *fname,unsigned long fname_len)
 {
 	C2F(intereduc)(fname,fname_len);
 	return 0;
