@@ -17,7 +17,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(scifreq)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_freq)(char *fname,unsigned long fname_len)
+int sci_freq(char *fname,unsigned long fname_len)
 {
 	C2F(scifreq)(fname,fname_len);
 	return 0;
