@@ -17,7 +17,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intfstair)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_fstair)(char *fname,unsigned long fname_len)
+int sci_fstair(char *fname,unsigned long fname_len)
 {
 	C2F(intfstair)(fname,fname_len);
 	return 0;
