@@ -19,7 +19,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(scitzer)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_tzer)(char *fname,unsigned long fname_len)
+int sci_tzer(char *fname,unsigned long fname_len)
 {
 	CheckRhs(4,4);
 	CheckLhs(2,3);
