@@ -14,15 +14,15 @@
 #include "stack-c.h"
 #include "callFunctionFromGateway.h"
 /*--------------------------------------------------------------------------*/
-static gw_generic_table Tab[]=
+static gw_generic_table Tab[] =
 {
-{C2F(sci_fromjava),"fromjava"},
-{C2F(sci_fromc),"fromc"}
+{sci_fromjava,"fromjava"},
+{sci_fromc,"fromc"}
 };
 /*--------------------------------------------------------------------------*/
 int gw_call_scilab(void)
 {  
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 	return 0;
 }
 /*--------------------------------------------------------------------------*/
