@@ -16,13 +16,13 @@
 /*--------------------------------------------------------------------------*/
 static gw_generic_table Tab[]=
 {
-{C2F(sci_completion),"completion"}
+{sci_completion,"completion"}
 };
 /*--------------------------------------------------------------------------*/
 int gw_completion(void)
 {  
 	Rhs = Max(0, Rhs);
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 
 	return 0;
 }
