@@ -13,12 +13,12 @@
 #ifndef __CONSOLEREAD_H__
 #define __CONSOLEREAD_H__
 /*--------------------------------------------------------------------------*/
-
+#include "dynlib_console.h"
 /**
 * ConsoleRead function
 * @return characters read in console
 */
-char *ConsoleRead(void);
+CONSOLE_IMPEXP char *ConsoleRead(void);
 
 /*--------------------------------------------------------------------------*/
 #endif /* __CONSOLEREAD_H__ */
