@@ -13,9 +13,11 @@
 /*--------------------------------------------------------------------------*/
 #ifndef __INTIALIZECONSOLE_H__
 #define __INTIALIZECONSOLE_H__
+
+#include "dynlib_console.h"
 #include "BOOL.h"
 
-BOOL InitializeConsole(void);
+CONSOLE_IMPEXP BOOL InitializeConsole(void);
 
 #endif /* __INTIALIZECONSOLE_H__ */
 /*--------------------------------------------------------------------------*/
