@@ -13,13 +13,14 @@
 #ifndef __SCILABLINESUPDATE_H__
 #define __SCILABLINESUPDATE_H__
 /*--------------------------------------------------------------------------*/
+#include "dynlib_console.h"
 #include "BOOL.h"
 /*--------------------------------------------------------------------------*/
 /**
 * Update scilines variable with the size of Java console
 * @return a boolean flag
 */
-BOOL ScilabLinesUpdate(void);
+CONSOLE_IMPEXP BOOL ScilabLinesUpdate(void);
 /*--------------------------------------------------------------------------*/
 #endif /*__SCILABLINESUPDATE_H__ */
 
