@@ -90,12 +90,6 @@
 /* 66 */                        #include "dynamic_parallel.h" /* parallel */
 /* 67 */                        #include "dynamic_gateways.h" /* ui_data */
 
-/*-------------------------------------
- * long jump to stop interface computation
- * @param n
- *-------------------------------------*/
-
-void errjump (int n);
 
 
 /** table of interfaces **/
@@ -111,4 +105,10 @@ typedef struct {
  */
 int C2F(callinterf) (int *k);
 
+/**
+ * long jump to stop interface computation
+ */
+void errjump ();
+
+
 #endif /*__CALLINTERF__*/
