@@ -15,6 +15,10 @@
 #ifndef STACK_SCI
 #define STACK_SCI
 
+#ifndef API_SCILAB_VERSION
+#pragma message("Using stack-c.h is deprecated. Please use api_scilab instead (try 'help api_scilab'). Note the stack-c.h API will be removed after Scilab 6.0.")
+#endif
+
 #include <string.h>
 
 #ifdef __cplusplus
@@ -35,39 +39,7 @@ extern "C" {
 #include "stack1.h"
 #include "stack2.h"
 #include "stack3.h"
-
-/*-------------------------------------------------
- * types
- * -------------------------------------------------*/
-
-typedef enum {
-  sci_matrix = 1 ,
-  sci_poly = 2 ,
-  sci_boolean = 4 ,
-  sci_sparse = 5  ,
-  sci_boolean_sparse = 6,
-  sci_matlab_sparse = 7, /* matlab sparse matrix  */
-  sci_ints = 8,
-  sci_handles =9,
-  sci_strings = 10,
-  sci_u_function = 11,
-  sci_c_function = 13 ,
-  sci_lib =  14,
-  sci_list = 15,
-  sci_tlist = 16,
-  sci_mlist = 17,
-  sci_pointer = 128, /* pointer */
-  sci_implicit_poly = 129,
-  sci_intrinsic_function = 130
-
-} sci_types;
-
- /* lufact pointer... Done for backward compatibility. 
-  *	sci_lufact_pointer has been added to be able to handle umfpack datatype
-  * Since the use of pointer data structur is very interesting for Scilab 
-  * we decided to rename it to remove the reference of the initial use.
-  */
-#define sci_lufact_pointer sci_pointer
+#include "sci_types.h"
 
 /*-------------------------------------------------
  * structure used for int matrix
@@ -220,7 +192,7 @@ static void initial_c1_local(void)
         { return 0;  }
 
 /* the real function error is defined in output_stream */
-#define Error(x) C2F(error)((c_local=x,&c_local))
+#define Error(x) SciError(x); sciprint(_("Error(x) is deprecated and will be removed in Scilab 5.4. Please consider SciError(x).\n"));
 
 #define Errorinfo(routinename,info) C2F(errorinfo)(routinename,(c_local=info, &c_local), strlen(routinename));
 
