@@ -12,6 +12,11 @@
 #ifndef STACK2_H
 #define  STACK2_H
 
+
+#ifndef API_SCILAB_VERSION
+#pragma message("Using stack2.h is deprecated. Please use api_scilab instead (try 'help api_scilab'). Note the stack2.h API will be removed after Scilab 6.0.")
+#endif
+
 #include "machine.h"
 
 /**
@@ -49,7 +54,6 @@ extern int C2F(ref2val)(void);
 extern int C2F(allops)(void);
 extern int C2F(putfunnam)(char *fname,int *lw, unsigned long);
 
-
 /* from somewhere (maybe stack1.h) */
 
 extern void C2F(setfeval)(char *,int *);
@@ -215,7 +219,6 @@ int C2F(in2str)(int *n, int *line, char *str, unsigned long str_len);
 int C2F(callscifun)(char *string, unsigned long string_len);
 int C2F(scifunction)(int *number, int *ptr, int *mlhs, int *mrhs);
 int C2F(scistring)(int *ifirst, char *thestring, int *mlhs, int *mrhs, unsigned long thestring_len);
-int C2F(getopcode)(char *string, unsigned long string_len);
 int C2F(scibuiltin)(int *number, int *ifun, int *ifin, int *mlhs, int *mrhs);
 int C2F(sciops)(int *number, int *op, int *mlhs, int *mrhs);
 int C2F(getrhssys)(int *lw, int *n, int *m, int *p, int *ptra, int *ptrb, int *ptrc, int *ptrd, int *ptrx0, double *h__);
