@@ -22,7 +22,8 @@
 #include "getstaticDebugInfo_Windows.h"
 #include "localization.h"
 #include "version.h"
-#include "withtk.h"
+#include "getversion.h"
+#include "dynamic_tclsci.h"
 #include "..\..\..\..\libs\pcre\pcre.h"
 /*--------------------------------------------------------------------------*/
 extern BOOL BuildWithVS8ExpressF2C(void);
@@ -71,7 +72,7 @@ char **getStaticDebugInfo_Windows(int *sizeArray)
 	if (str_info)
 	{
 
-	#ifdef __INTEL__
+	#ifdef __INTEL_COMPILER
 		sprintf(str_info,"Compiled with %s","Intel compiler");
 	#elif defined _MSC_VER
 		sprintf(str_info,"Compiled with %s","Microsoft compiler");
@@ -98,7 +99,7 @@ char **getStaticDebugInfo_Windows(int *sizeArray)
 		outputDynamicList = appendStringStaticDebugInfo(outputDynamicList,&nb_info,str_info);
 	}
 
-	if ( withtk() )
+	if ( with_tk() )
 	{
 		str_info = (char*)MALLOC(sizeof(char)*BUFFER_LEN);
 		if (str_info)
