@@ -15,7 +15,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intlstsize)(); /* fortran */
 /*--------------------------------------------------------------------------*/
-int C2F(sci_lstsize)(char *fname,unsigned long fname_len)
+int sci_lstsize(char *fname,unsigned long fname_len)
 {
     C2F(intlstsize)();
 	return 0;
