@@ -14,15 +14,14 @@
 #ifndef __GW_DIFFERENTIAL_EQUATIONS4__
 #define __GW_DIFFERENTIAL_EQUATIONS4__
 /*--------------------------------------------------------------------------*/
-#include "machine.h"
-#include "api_scilab.h"
+#include "dynlib_differential_equations.h"
 /*--------------------------------------------------------------------------*/
-int gw_differential_equations4(void);
+DIFFERENTIAL_EQUATIONS_IMPEXP int gw_differential_equations4(void);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_intg)(char *fname,unsigned long fname_len);
-int C2F(sci_int2d)(char *fname,unsigned long fname_len);
-int C2F(sci_int3d)(char *fname,unsigned long fname_len);
-int C2F(sci_feval)(char *fname,unsigned long fname_len);
+int sci_intg(char *fname,unsigned long fname_len);
+int sci_int2d(char *fname,unsigned long fname_len);
+int sci_int3d(char *fname,unsigned long fname_len);
+int sci_feval(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
 #endif  /* __GW_DIFFERENTIAL_EQUATIONS4__ */
 /*--------------------------------------------------------------------------*/
