@@ -11,10 +11,11 @@
  */
 /*--------------------------------------------------------------------------*/ 
 #include "gw_differential_equations1.h"
+#include "machine.h"
 /*--------------------------------------------------------------------------*/
 extern int C2F(intg)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_intg)(char *fname,unsigned long fname_len)
+int sci_intg(char *fname,unsigned long fname_len)
 {
 	C2F(intg)(fname,fname_len);
 	return 0;
