@@ -14,6 +14,7 @@
 #define __IDMIN_H__
 
 #include "machine.h" /* C2F */
+#include "dynlib_elementary_functions.h"
 
 /**
  * finds the index of the first element having minimum value 
@@ -24,7 +25,7 @@
  * @param incr indice
  * @return 0
 */
-int C2F(idmin)(int *n, double *x, int *incx);
+ELEMENTARY_FUNCTIONS_IMPEXP int C2F(idmin)(int *n, double *x, int *incx);
 
 #endif /* __IDMIN_H__ */
 /*--------------------------------------------------------------------------*/ 
