@@ -13,9 +13,12 @@
 #ifndef __VFINITE__
 #define __VFINITE__
 
-#include "doublecomplex.h" 
+#include "machine.h"
+#include "doublecomplex.h"
+#include "dynlib_elementary_functions.h"
 
-int C2F(vfinite)(int *n, double *v);
-int C2F(vfiniteComplex)(int *n, doublecomplex *v);
+
+ELEMENTARY_FUNCTIONS_IMPEXP int C2F(vfinite)(int *n, double *v);
+ELEMENTARY_FUNCTIONS_IMPEXP int C2F(vfiniteComplex)(int *n, doublecomplex *v);
 
 #endif /* !__VFINITE__ */
