@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intabs)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_abs)(char *fname,unsigned long fname_len)
+int sci_abs(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intabs)(id);
