@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intacos)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_acos)(char *fname,unsigned long fname_len)
+int sci_acos(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intacos)(id);
