@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intconj)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_conj)(char *fname,unsigned long fname_len)
+int sci_conj(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intconj)(id);
