@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intcos)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_cos)(char *fname,unsigned long fname_len)
+int sci_cos(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intcos)(id);
