@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intdiag)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_diag)(char *fname,unsigned long fname_len)
+int sci_diag(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intdiag)(id);
