@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intexp)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_exp)(char *fname,unsigned long fname_len)
+int sci_exp(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intexp)(id);
