@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intfloor)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_floor)(char *fname,unsigned long fname_len)
+int sci_floor(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intfloor)(id);
