@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intint)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_int)(char *fname,unsigned long fname_len)
+int sci_int(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intint)(id);
