@@ -15,7 +15,7 @@
 /*--------------------------------------------------------------------------*/
 int C2F(intisequalvar)(char * fname, int *job, long int fl); /* the gateway */
 /*--------------------------------------------------------------------------*/
-int C2F(sci_isequalbitwise)(char *fname,unsigned long fname_len)
+int sci_isequalbitwise(char *fname,unsigned long fname_len)
 {
 	int job= 0;
 	C2F(intisequalvar)(fname, (job=0,&job),(unsigned long)strlen(fname) );
