@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intisreal)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_isreal)(char *fname,unsigned long fname_len)
+int sci_isreal(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intisreal)(id);
