@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intkron)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_kron)(char *fname,unsigned long fname_len)
+int sci_kron(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intkron)(id);
