@@ -10,14 +10,18 @@
  *
  */
 /*--------------------------------------------------------------------------*/ 
+#include <string.h>
 #include "gw_elementary_functions.h"
+#include "warningmode.h"
+#include "localization.h"
+#include "sciprint.h"
 /*--------------------------------------------------------------------------*/
 extern int C2F(intmaxi)(char *fname,int *id,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_maxi)(char *fname,unsigned long fname_len)
+int sci_maxi(char *fname, unsigned long fname_len)
 {
 	static int id[6];
-	C2F(intmaxi)(fname,id,fname_len);
+	C2F(intmaxi)(fname, id, fname_len);
 	return 0;
 }
 /*--------------------------------------------------------------------------*/
