@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intnearfl)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_nearfloat)(char *fname,unsigned long fname_len)
+int sci_nearfloat(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intnearfl)(id);
