@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intprod)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_prod)(char *fname,unsigned long fname_len)
+int sci_prod(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intprod)(id);
