@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intround)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_round)(char *fname,unsigned long fname_len)
+int sci_round(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intround)(id);
