@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(inttestmatrix)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_testmatrix)(char *fname,unsigned long fname_len)
+int sci_testmatrix(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(inttestmatrix)(id);
