@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(inttril)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_tril)(char *fname,unsigned long fname_len)
+int sci_tril(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(inttril)(id);
