@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intzeros)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_zeros)(char *fname,unsigned long fname_len)
+int sci_zeros(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intzeros)(id);
