@@ -13,21 +13,22 @@
 /*--------------------------------------------------------------------------*/
 #ifndef __URIFILETOFILENAME_H__
 #define __URIFILETOFILENAME_H__
-
+#include "dynlib_fileio.h"
 #include "BOOL.h"
+
 /**
 * convert URI File (file://path/filename.ext) to standard filename
 * @param[in] uri : a string URI file
 * @return a filename
 */
-char *URIFileToFilename(char *uri);
+FILEIO_IMPEXP char *URIFileToFilename(char *uri);
 
 /**
 * check if it is a URIFile
 * @param [in] uri : a string URI file
 * @return TRUE or FALSE;
 */
-BOOL isURIFile(char *uri);
+FILEIO_IMPEXP BOOL isURIFile(char *uri);
 
 #endif /* __URIFILETOFILENAME_H__ */
 /*--------------------------------------------------------------------------*/
