@@ -13,6 +13,7 @@
 #ifndef __GETFILETYPE_H__
 #define __GETFILETYPE_H__
 
+#include "dynlib_fileio.h"
 #include "machine.h"
 
 /**
@@ -22,7 +23,7 @@
  * @param type  
  * @param ierr  
  */
-void C2F(getfiletype)(int *fd, int *type, int *ierr);
+FILEIO_IMPEXP void C2F(getfiletype)(int *fd, int *type, int *ierr);
 
 #endif /* __GETFILETYPE_H__ */
 /*--------------------------------------------------------------------------*/
