@@ -13,6 +13,8 @@
 #ifndef __REMOVEDIR_H__
 #define __REMOVEDIR_H__
 
+#include <wchar.h>
+#include "dynlib_fileio.h"
 #include "BOOL.h" /* BOOL */
 
 /**
@@ -20,7 +22,14 @@
 * @param path the directory
 * @return the result of the operation
 */
-BOOL removedir(char *path);
+FILEIO_IMPEXP BOOL removedir(char *path);
+
+/**
+* Remove a directory
+* @param path the directory (wide string)
+* @return the result of the operation
+*/
+FILEIO_IMPEXP BOOL removedirW(wchar_t *pathW);
 
 #endif /* __REMOVEDIR_H__ */
 /*--------------------------------------------------------------------------*/ 
