@@ -11,21 +11,24 @@
  *
  */
 /*--------------------------------------------------------------------------*/
+#include <string.h>
 #include "gw_fileio.h"
 #include "stack-c.h"
 #include "MALLOC.h"
 #include "Scierror.h"
+#ifdef _MSC_VER
+#include "strdup_windows.h"
+#endif
 /*--------------------------------------------------------------------------*/
-int C2F(sci_filesep)(char *fname,unsigned long fname_len)
+int sci_filesep(char *fname,unsigned long fname_len)
 {
 	static int n1,m1;
-	char *separator=NULL;
+	char *separator = NULL;
 
 	CheckRhs(0,0);
 	CheckLhs(1,1);
 
-	separator=(char*)MALLOC(sizeof(char)*(strlen(DIR_SEPARATOR)+1));
-	if (separator) strcpy(separator,DIR_SEPARATOR);
+	separator = strdup(DIR_SEPARATOR);
 
 	n1 = 1;
 	CreateVarFromPtr(Rhs+1,STRING_DATATYPE,(m1=(int)strlen(separator), &m1),&n1,&separator);
