@@ -40,7 +40,7 @@ int sci_mput(char *fname,unsigned long fname_len)
 	}
 	else
 	{
-		Scierror(999, _("%s: Wrong type for input argument #%d: A integer expected.\n"), fname,1);
+		Scierror(999, _("%s: Wrong type for input argument #%d: An integer expected.\n"), fname,1);
 		return 0;
 	}
 	
@@ -75,13 +75,13 @@ int sci_mput(char *fname,unsigned long fname_len)
 			}
 			else
 			{
-				Scierror(999, _("%s: Wrong size for input argument #%d: A integer expected.\n"), fname,2);
+				Scierror(999, _("%s: Wrong size for input argument #%d: An integer expected.\n"), fname,2);
 				return 0;
 			}
 		}
 		else
 		{
-			Scierror(999, _("%s: Wrong type for input argument #%d: A integer expected.\n"), fname,2);
+			Scierror(999, _("%s: Wrong type for input argument #%d: An integer expected.\n"), fname,2);
 			return 0;
 		}
 	}
