@@ -13,6 +13,8 @@
 #ifndef __ISDRIVE_H__
 #define __ISDRIVE_H__
 
+#include <wchar.h>
+
 #include "BOOL.h" /* BOOL */
 
 /**
@@ -23,5 +25,14 @@
 */
 BOOL isDrive(const char *strname);
 
+/**
+* check if strname is a drive (only for windows)
+* @param[in] a wide string 
+* @return TRUE or FALSE
+* returns always false on linux
+*/
+
+BOOL isDriveW(const wchar_t *wcstrname);
+
 #endif
 /*--------------------------------------------------------------------------*/ 
