@@ -4,6 +4,7 @@
  * Copyright (C) 2002 - 2004 - INRIA - Djalel Abdemouche
  * Copyright (C) 2004 - 2006 - INRIA - Fabrice Leray
  * Copyright (C) 2005 - INRIA - Jean-Baptiste Silvy
+ * Copyright (C) 2009 - DIGITEO - Pierre Lando
  * 
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
@@ -21,20 +22,10 @@
 #ifndef __SCI_OBJECT_STRUCTURE__
 #define __SCI_OBJECT_STRUCTURE__
 
-
-
-/*en fait il n'y a essentiellement besion que de Math.h dans stack-c.h
-  sauf pour les callback (il faudrait creer une fonction et l'appeler) */
-#include "stack-c.h"
+#include "dynlib_graphics.h"
 #include "StringMatrix.h"
 #include "DoublyLinkedList.h"
 
-#ifdef _MSC_VER
-#undef Top 
-#include <windows.h>
-#define Top C2F(vstk).top
-#endif
-
 #define NUMCOLORS_SCI 32
 #define SCI_FIGURE_NAME_LENGTH 256
 /* Renvoi le pointeur sur la structure */
@@ -197,8 +188,8 @@ typedef struct
   int fillcolor;
   /** Wheter the object is filled or not */
   BOOL isfilled;
-  /** associeted to PEN or mark size */
-  int linewidth;
+  /** thickness of lines */
+  double linewidth;
   /** */
   BOOL isline;
   /** */
@@ -297,6 +288,7 @@ typedef struct
   int numColors ;
   BOOL autoResizeMode;
 	char * infoMessage; /**< String displayed in the info bar of the graphic window */
+	int antialiasingQuality;
 }
 FigureModelData ;
 
@@ -626,7 +618,7 @@ typedef enum {FLAT_RELIEF, GROOVE_RELIEF, RAISED_RELIEF, RIDGE_RELIEF, SOLID_REL
 typedef enum {LEFT_ALIGNMENT, CENTER_ALIGNMENT, RIGHT_ALIGNMENT, TOP_ALIGNMENT, MIDDLE_ALIGNMENT, BOTTOM_ALIGNMENT} UicontrolAlignment;
 
 /* the part of the drawn box for 3d axis */
-typedef enum { BT_OFF = FALSE, BT_ON = TRUE, BT_HIDDEN_AXIS, BT_BACK_HALF } EAxesBoxType ;
+typedef enum { BT_OFF = FALSE, BT_ON = TRUE, BT_HIDDEN_AXES, BT_BACK_HALF } EAxesBoxType ;
 
 typedef struct 
 {  
