@@ -14,12 +14,14 @@
 #ifndef __GETDICTIONARYGETPROPERTIES_H__
 #define __GETDICTIONARYGETPROPERTIES_H__
 
+#include "dynlib_graphics.h"
+
 /**
 * get all "Get" Handle graphics properties name
 * @param[out] size of string matrix
 * @return a string matrix
 */
-char **getDictionaryGetProperties(int *sizearray);
+GRAPHICS_IMPEXP char **getDictionaryGetProperties(int *sizearray);
 
 #endif /* __GETDICTIONARYGETPROPERTIES_H__ */
 /*--------------------------------------------------------------------------*/
