@@ -18,14 +18,16 @@
 #ifndef _GRAPHIC_MODULE_CLOSE_H_
 #define _GRAPHIC_MODULE_CLOSE_H_
 
+#include "dynlib_graphics.h"
+
 /**
  * Routine creating all needed objetcs for the module
  */
-void loadGraphicModule( void ) ;
+GRAPHICS_IMPEXP void loadGraphicModule( void ) ;
 
 /**
  * Closing function freeing all memory used by the graphic module
  */
-void closeGraphicModule( void ) ;
+GRAPHICS_IMPEXP void closeGraphicModule( void ) ;
 
 #endif /* _GRAPHIC_MODULE_CLOSE_H_ */
