@@ -15,9 +15,8 @@
 /* desc : interface for clear_pixmap routine                              */
 /*------------------------------------------------------------------------*/
 
-#include "sci_show_pixmap.h"
+#include "gw_graphics.h"
 #include "stack-c.h"
-#include "GetProperty.h"
 #include "DrawObjects.h"
 #include "CurrentObjectsManagement.h"
 
