@@ -17,17 +17,14 @@
 /* desc : interface for copy routine                                      */
 /*------------------------------------------------------------------------*/
 
-#include "sci_copy.h"
-#include "stack-c.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
-#include "ObjectStructure.h"
-#include "DrawObjects.h"
+#include "stack-c.h"
 #include "GetProperty.h"
 #include "CloneObjects.h"
 #include "DrawingBridge.h"
 #include "localization.h"
 #include "Scierror.h"
+#include "HandleManagement.h"
 /*--------------------------------------------------------------------------*/
 int sci_copy(char *fname,unsigned long fname_len)
 {  
