@@ -15,12 +15,7 @@
 /* file: sci_draw.h                                                       */
 /* desc : interface for draw routine                                      */
 /*------------------------------------------------------------------------*/
-
-#include "sci_draw.h"
-#include "GetProperty.h"
-#include "SetProperty.h"
-#include "DrawObjects.h"
-#include "BuildObjects.h"
+#include "stack-c.h"
 #include "gw_graphics.h"
 #include "HandleManagement.h"
 #include "CurrentObjectsManagement.h"
