@@ -16,12 +16,8 @@
 /* desc : interface for drawlater routine                                 */
 /*------------------------------------------------------------------------*/
 
-#include "sci_drawlater.h"
-#include "stack-c.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
-#include "GetProperty.h"
-#include "ObjectStructure.h"
+#include "stack-c.h"
 #include "CurrentObjectsManagement.h"
 #include "GraphicSynchronizerInterface.h"
 #include "SetProperty.h"
