@@ -15,9 +15,7 @@
 /* file: sci_geom3d.c                                                     */
 /* desc : interface for geom3d routine                                    */
 /*------------------------------------------------------------------------*/
-
-#include "sci_geom3d.h"
-#include "BuildObjects.h"
+#include "stack-c.h"
 #include "gw_graphics.h"
 #include "GetProperty.h"
 #include "CurrentObjectsManagement.h"
