@@ -15,14 +15,12 @@
 /* desc : interface for xaxis routine                                     */
 /*------------------------------------------------------------------------*/
 
-#include "sci_is_handle_valid.h"
 #include "gw_graphics.h"
 #include "stack-c.h"
 #include "HandleManagement.h"
 #include "Scierror.h"
 #include "localization.h"
 #include "getPropertyAssignedValue.h"
-#include "CurrentObjectsManagement.h"
 
 /*--------------------------------------------------------------------------*/
 int sci_is_handle_valid(char *fname,unsigned long fname_len)
