@@ -16,14 +16,10 @@
 /* desc : interface for matplot routine                                   */
 /*------------------------------------------------------------------------*/
 
-#include "sci_matplot.h"
+#include "gw_graphics.h"
 #include "GetCommandArg.h"
 #include "DefaultCommandArg.h"
-#include "sci_demo.h"
 #include "BuildObjects.h"
-#include "gw_graphics.h"
-#include "DestroyObjects.h"
-#include "GetProperty.h"
 #include "sciCall.h"
 #include "stack-c.h"
 #include "localization.h"
