@@ -16,13 +16,9 @@
 /* desc : interface for param3d1 routine                                  */
 /*------------------------------------------------------------------------*/
 
-#include "sci_param3d1.h"
-#include "sci_demo.h"
+#include "gw_graphics.h"
 #include "GetCommandArg.h"
 #include "BuildObjects.h"
-#include "gw_graphics.h"
-#include "DestroyObjects.h"
-#include "GetProperty.h"
 #include "sciCall.h"
 #include "MALLOC.h"
 #include "stack-c.h"
