@@ -19,18 +19,15 @@
 
 #include <stdio.h>
 
-#include "sci_plot3d.h"
-#include "stack-c.h"
-#include "sci_demo.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
-#include "GetProperty.h"
+#include "stack-c.h"
+#include "BuildObjects.h"
 #include "GetCommandArg.h"
-#include "DestroyObjects.h"
 #include "MALLOC.h"
 #include "sciCall.h"
 #include "localization.h"
 #include "Scierror.h"
+
 /*--------------------------------------------------------------------------*/
 int sci_plot3d( char * fname, unsigned long fname_len )
 {
