@@ -16,14 +16,13 @@
 /* desc : interface for rotate_axes routine                               */
 /*------------------------------------------------------------------------*/
 
-#include "sci_rotate_axes.h"
+#include "gw_graphics.h"
 #include "stack-c.h"
 #include "Scierror.h"
 #include "Interaction.h"
 #include "localization.h"
 #include "HandleManagement.h"
 #include "getPropertyAssignedValue.h"
-#include "returnProperty.h"
 #include "GetProperty.h"
 #include "CurrentObjectsManagement.h"
 
