@@ -16,12 +16,10 @@
 /* desc : interface for xarc routine                                      */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xarc.h"
+#include "gw_graphics.h"
 #include "sciCall.h"
 #include "GetProperty.h"
 #include "stack-c.h"
-#include "BuildObjects.h"
-#include "gw_graphics.h"
 #include "CurrentObjectsManagement.h"
 #include "GraphicSynchronizerInterface.h"
 #include "DrawingBridge.h"
