@@ -16,15 +16,11 @@
 /* desc : interface for xarrows routine                                   */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xarrows.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
 #include "sciCall.h"
 #include "stack-c.h"
-#include "GetProperty.h"
 #include "localization.h"
 #include "Scierror.h"
-#include "DrawObjects.h"
 #include "CurrentObjectsManagement.h"
 #include "DrawingBridge.h"
 /*--------------------------------------------------------------------------*/
@@ -69,7 +65,7 @@ int sci_xarrows(char *fname,unsigned long fname_len)
     flag = 0;
   }
   
-  Objsegs (style,flag,mn2,stk(l1),stk(l2),arsize);
+  Objsegs (style,flag,mn2,stk(l1),stk(l2),NULL,arsize);
   
   sciDrawObj(sciGetCurrentObj());
 
