@@ -16,12 +16,8 @@
 /* desc : interface for xfpoly routine                                    */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xfpoly.h"
-#include "stack-c.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
-#include "SetProperty.h"
-#include "ObjectStructure.h"
+#include "stack-c.h"
 #include "DrawObjects.h"
 #include "sciCall.h"
 #include "GetProperty.h"
