@@ -16,14 +16,11 @@
 /* desc : interface for xfpolys routine                                   */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xfpolys.h"
+#include "gw_graphics.h"
 #include "stack-c.h"
 #include "BuildObjects.h"
-#include "gw_graphics.h"
 #include "Scierror.h"
-#include "ObjectStructure.h"
 #include "sciCall.h"
-#include "SetProperty.h"
 #include "GetProperty.h"
 #include "DrawObjects.h"
 #include "CurrentObjectsManagement.h"
