@@ -16,10 +16,8 @@
 /* desc : interface for xgetech routine                                   */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xgetech.h"
-#include "stack-c.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
+#include "stack-c.h"
 #include "PloEch.h"
 
 /*--------------------------------------------------------------------------*/
