@@ -16,12 +16,9 @@
 /* desc : interface for xname routine                                     */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xname.h"
-#include "stack-c.h"
-#include "GetProperty.h"
-#include "SetProperty.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
+#include "stack-c.h"
+#include "SetProperty.h"
 #include "CurrentObjectsManagement.h"
 
 /*--------------------------------------------------------------------------*/
