@@ -16,10 +16,8 @@
 /* desc : interface for xsetech routine                                   */
 /*------------------------------------------------------------------------*/
 
-#include "sci_xsetech.h"
-#include "stack-c.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
+#include "stack-c.h"
 #include "GetCommandArg.h"
 #include "PloEch.h"
 
