@@ -17,16 +17,9 @@
 /* desc : interface for xstringb routine                                  */
 /*------------------------------------------------------------------------*/
 
-#include <string.h>
-
-#include "sci_xstringb.h"
-#include "stack-c.h"
-#include "sci_demo.h"
-#include "BuildObjects.h"
 #include "gw_graphics.h"
+#include "stack-c.h"
 #include "Scierror.h"
-#include "GetProperty.h"
-#include "MALLOC.h"
 #include "sciCall.h"
 #include "freeArrayOfString.h"
 #include "localization.h"
