@@ -17,7 +17,7 @@
 /* desc : function to retrieve in Scilab the format_n field of            */
 /*        a handle                                                        */
 /*------------------------------------------------------------------------*/
-
+#include <stdlib.h>
 #include "getHandleProperty.h"
 #include "GetProperty.h"
 #include "returnProperty.h"
@@ -29,9 +29,12 @@ int get_format_n_property( sciPointObj * pobj )
 {
   if ( sciGetEntityType (pobj) != SCI_AXES )
   {
-    Scierror(999, _("%s property does not exist for this handle.\n"),"format_n");
+    Scierror(999, _("'%s' property does not exist for this handle.\n"),"format_n");
     return -1;
   }
+  if(pAXES_FEATURE (pobj)->format == NULL)
+    return sciReturnString("");
+  
   return sciReturnString( pAXES_FEATURE (pobj)->format ) ;
 }
 /*------------------------------------------------------------------------*/
