@@ -30,7 +30,7 @@ int get_tics_style_property( sciPointObj * pobj )
 
 	if ( sciGetEntityType( pobj ) != SCI_AXES )
   {
-    Scierror(999, _("%s property does not exist for this handle.\n"), "tics_style") ;
+    Scierror(999, _("'%s' property does not exist for this handle.\n"), "tics_style") ;
     return -1 ;
   }
 
