@@ -31,7 +31,7 @@ int get_z_bounds_property( sciPointObj * pobj )
   double zBounds[2];
   if (sciGetEntityType (pobj) != SCI_FEC)
   {
-    Scierror(999, _("%s property does not exist for this handle.\n"),"z_bounds") ;
+    Scierror(999, _("'%s' property does not exist for this handle.\n"),"z_bounds") ;
     return -1 ;
   }
 
