@@ -25,6 +25,8 @@
 #ifndef _SET_HANDLE_PROPERTY_H_
 #define _SET_HANDLE_PROPERTY_H_
 
+#include <stdlib.h>
+
 #include "ObjectStructure.h"
 
 #include "SetUimenuLabel.h"
@@ -48,6 +50,7 @@
 #include "SetUicontrolVerticalAlignment.h"
 #include "SetUicontrolFontName.h"
 #include "SetUicontrolSliderStep.h"
+#include "SetUimenuChecked.h"
 
 
 int set_color_map_property(            sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol ) ;
@@ -178,6 +181,7 @@ int set_legend_location_property(      sciPointObj * pobj, size_t stackPointer,
 int set_filled_property(               sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol ) ;
 int set_outside_colors_property(       sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol ) ;
 int set_color_range_property(          sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol ) ;
-int set_grid_position_property(        sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol );
+int set_grid_position_property(        sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol ) ;
+int set_anti_aliasing_property(        sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol ) ;
 
 #endif /* _SET_HANDLE_PROPERTY_H_ */
