@@ -19,8 +19,6 @@
 /*------------------------------------------------------------------------*/
 
 #include "setHandleProperty.h"
-#include "SetProperty.h"
-#include "SetPropertyStatus.h"
 
 /*------------------------------------------------------------------------*/
 int set_figure_position_property( sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol )
