@@ -12,7 +12,7 @@
 
 #ifndef __GET_UICONTROL_FONTANGLE_H__
 #define __GET_UICONTROL_FONTANGLE_H__
-
+#include "dynlib_gui.h"
 #include "ObjectStructure.h"
 #include "returnProperty.h"
 
@@ -22,6 +22,6 @@
  * @param pobj Scilab object corresponding to the uicontrol
  * @return true if the font angle property has been correcty got
  */
-int GetUicontrolFontAngle(sciPointObj * pobj);
+GUI_IMPEXP int GetUicontrolFontAngle(sciPointObj * pobj);
 
 #endif /* __GET_UICONTROL_FONTANGLE_H__ */
