@@ -12,7 +12,7 @@
 
 #ifndef __GET_UICONTROL_MIN_H__
 #define __GET_UICONTROL_MIN_H__
-
+#include "dynlib_gui.h"
 #include "ObjectStructure.h"
 #include "returnProperty.h"
 
@@ -22,6 +22,6 @@
  * @param pobj Scilab object corresponding to the uicontrol
  * @return true if the min property has been correcty got
  */
-int GetUicontrolMin(sciPointObj * pobj);
+GUI_IMPEXP int GetUicontrolMin(sciPointObj * pobj);
 
 #endif /* __GET_UICONTROL_MIN_H__ */
