@@ -12,7 +12,7 @@
 
 #ifndef __GET_UIOBJECT_TAG_H__
 #define __GET_UIOBJECT_TAG_H__
-
+#include "dynlib_gui.h"
 #include "ObjectStructure.h"
 #include "returnProperty.h"
 
@@ -22,6 +22,6 @@
  * @param pobj Scilab object corresponding to the uicontrol
  * @return true if the tag property has been correcty got
  */
-int GetUiobjectTag(sciPointObj * pobj);
+GUI_IMPEXP int GetUiobjectTag(sciPointObj * pobj);
 
 #endif /* __GET_UIOBJECT_TAG_H__ */
