@@ -129,7 +129,7 @@ int sci_uigetfont(char *fname,unsigned long fname_len)
   fontChooserID = createFontChooser();
 
   /* Default font */
-  if (fontNameAdr != 0)
+  if (fontNameAdr != NULL)
     {
       setFontChooserFontName(fontChooserID, getStringMatrixFromStack((size_t)fontNameAdr)[0]);
     }
@@ -227,7 +227,7 @@ int sci_uigetfont(char *fname,unsigned long fname_len)
   LhsVar(4) = Rhs+4;
   
   C2F(putlhsvar)();
-  freeArrayOfString(fontNameAdr, fontNameSize);
+  if (fontNameSize) freeArrayOfString(fontNameAdr, fontNameSize);
   return TRUE;
 }
 /*--------------------------------------------------------------------------*/
