@@ -33,7 +33,7 @@ int GetUicontrolSliderStep(sciPointObj* sciObj)
     }
   else
     {
-      Scierror(999, _("No '%s' property for this object.\n"), "SliderStep");
+      Scierror(999, const_cast<char*>(_("No '%s' property for this object.\n")), "SliderStep");
       return FALSE;
     }
 }
