@@ -21,7 +21,7 @@ int GetUicontrolStyle(sciPointObj* sciObj)
     }
   else
     {
-      Scierror(999, _("No '%s' property for this object.\n"), "Style");
+		Scierror(999, const_cast<char*>(_("No '%s' property for this object.\n")), "Style");
       return FALSE;
     }
   
