@@ -19,9 +19,13 @@ import java.util.StringTokenizer;
 import javax.swing.ImageIcon;
 import javax.swing.JFileChooser;
 import javax.swing.JFrame;
+import javax.swing.JOptionPane;
+
+import org.scilab.modules.localization.Messages;
 
 import org.scilab.modules.gui.filechooser.FileChooserInfos;
 import org.scilab.modules.gui.filechooser.SimpleFileChooser;
+import org.scilab.modules.gui.utils.ConfigManager;
 import org.scilab.modules.gui.utils.SciFileFilter;
 
 /**
@@ -39,6 +43,7 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 	private int selectionSize; 	
 	private int filterIndex;
 	private int maskSize;
+	private int dialogType;
 	
 	private String[] maskDescription;	
 
@@ -47,6 +52,8 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 	 */
 	public SwingScilabFileChooser() {
 		super();
+		
+		
 		//System.out.println("[Constructor] SwingScilabFileChooser");
 		/** Bug 3231 fixed: do not explore all zip files on desktop under Windows */
 		//putClientProperty("FileChooser.useShellFolder", Boolean.FALSE);
@@ -54,6 +61,8 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 		 * Bug 4187 fixed: uigetdir() opens on "Desktop" and not on "Computer" on windows
 		 * No need to use 'putClientProperty' anymore (bug 3231)
 		 */
+		/* Bug 5111 : The Current directory have to be set before */
+		super.setCurrentDirectory(new File(ConfigManager.getLastOpenedDirectory()));
 	}	
 
 	/**
@@ -76,17 +85,16 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 		
 		//If the mask description is empty we allocate description 
 		//according to the extensions given
-		if (fileMaskDescription.length == 0) {
-			maskDescription = new String[mask.length];			
+		if (fileMaskDescription == null || fileMaskDescription.length == 0) {
 			for (int i = 0; i < mask.length; i++) {
-				super.addChoosableFileFilter(new SciFileFilter(mask[i], maskDescription[i], i/*, maskSize*/));
+				super.addChoosableFileFilter(new SciFileFilter(mask[i], null, i/*, maskSize*/));
 			}
 		} else {
 			//If the mask description is filled
 			//we use those descriptions given by the user
 			this.maskDescription = fileMaskDescription;
 			for (int i = 0; i < mask.length; i++) {
-				super.addChoosableFileFilter(new SciFileFilter(mask[i], maskDescription[i],i/*, maskSize*/));
+				super.addChoosableFileFilter(new SciFileFilter(mask[i], maskDescription[i], i/*, maskSize*/));
 			}
 		}
 	}
@@ -117,10 +125,14 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 	 * Display this chooser and wait for user selection 
 	 */
 	public void displayAndWait() {
-		
 		JFrame parentFrame = new JFrame();
 		parentFrame.setIconImage(new ImageIcon(System.getenv("SCI") + "/modules/gui/images/icons/scilab.png").getImage());
-		int returnValue = this.showOpenDialog(parentFrame);
+		int returnValue = 0;
+		if (this.dialogType == JFileChooser.SAVE_DIALOG) {
+			returnValue = this.showSaveDialog(parentFrame);
+		} else {
+			returnValue = this.showOpenDialog(parentFrame);
+		}
 		
 		//User validate the uigetfile
 		if (returnValue == APPROVE_OPTION) {
@@ -132,15 +144,51 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 				for (int i = 0; i < files.length; i++) {
 					selection[i] = files[i].getAbsolutePath();
 					selectionPath = files[i].getParentFile().getPath();
-					selectionFileNames[i] = files[i].getAbsolutePath().substring(selectionPath.length() + 1);
+					selectionFileNames[i] = files[i].getName();
 				}					
 			} else {
 				File file = this.getSelectedFile();
+				
+				if (this.dialogType == JFileChooser.SAVE_DIALOG) {
+					//Test if there is a file with the same name	
+					if (file.exists()) {
+						int actionDialog = JOptionPane.showConfirmDialog(this, 
+								Messages.gettext("Replace existing file?"), 
+								Messages.gettext("File already exist"), 
+								JOptionPane.YES_NO_OPTION);
+
+						if (actionDialog != JOptionPane.YES_OPTION) {
+							// Same as cancel case
+							selection = new String[1];
+							selection[0] = "";
+							selectionSize = 0;
+							selectionPath = "";	
+							selectionFileNames = new String[1];
+							selectionFileNames[0] = "";
+							//set the filter index of the JFileChooser at 0 if "cancel" button was selected
+							filterIndex = 0;
+						
+							//return the filechooser's informations 
+							//they are stocked into FileChooserInfos
+							FileChooserInfos.getInstance().setSelection(selection);
+							FileChooserInfos.getInstance().setSelectionPathName(selectionPath);
+							FileChooserInfos.getInstance().setSelectionFileNames(selectionFileNames);
+							FileChooserInfos.getInstance().setSelectionSize(selectionSize);			
+							FileChooserInfos.getInstance().setFilterIndex(filterIndex);			
+							return;
+						}
+					}
+				}
+
 				selection = new String[1];
 				selection[0] = file.getAbsolutePath();
-				selectionPath = file.getParentFile().getPath();
+				if (getFileSelectionMode() == DIRECTORIES_ONLY) {
+					selectionPath = file.getPath();
+				} else {
+					selectionPath = file.getParentFile().getPath();
+				}
 				selectionFileNames = new String[1];
-				selectionFileNames[0] = file.getAbsolutePath().substring(selectionPath.length() + 1);
+				selectionFileNames[0] = file.getName();
 				selectionSize = 1;						
 			}
 			
@@ -153,11 +201,12 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 			
 			//set the filter index at the last index 
 			//of the list box if the mask "All files" is selected  
-			javax.swing.filechooser.FileFilter AllFilesSelected = getFileFilter();
-			if (AllFilesSelected.getDescription().equals("All Files")){
+			javax.swing.filechooser.FileFilter allFilesSelected = getFileFilter();
+			if (allFilesSelected.getDescription().equals("All Files")) {
 				FileChooserInfos.getInstance().setFilterIndex(maskSize + 1);
 			}
-			
+			//TODO
+			ConfigManager.saveLastOpenedDirectory(selectionPath);
 		//User cancel the uigetfile	
 		} else {			
 			selection = new String[1];
@@ -244,4 +293,12 @@ public class SwingScilabFileChooser extends JFileChooser implements SimpleFileCh
 	public void setFilterIndex(int filterIndex) {
 		setFilterIndex(filterIndex);
 	}
+	
+	/**
+	 * Set the dialog type (save or open a file ?)
+	 * @param dialogType the dialog type
+	 */
+	public void setUiDialogType(int dialogType) {
+		this.dialogType = dialogType;
+	}
 }
