@@ -16,25 +16,49 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 import ncsa.hdf.hdf5lib.exceptions.HDF5Exception;
 
-import org.scilab.modules.hdf5.scilabTypes.ScilabBoolean;
+import org.scilab.modules.types.ScilabBoolean;
 
-public class H5ReadScilabBoolean {
+/**
+ * H5ReadScilabBoolean
+ */
+public final class H5ReadScilabBoolean {
 
-    public static void readData(int dataSetId, ScilabBoolean data) throws NullPointerException, HDF5Exception {
+    /**
+     * Private Constructor for utility class
+     */
+    private H5ReadScilabBoolean() { }
+    
+    /**
+     * readData
+     * @param dataSetId the dataset ID to read.
+     * @param data A data structure that will be filled.
+     * @throws HDF5Exception .
+     */
+    public static void readData(int dataSetId, ScilabBoolean data) throws HDF5Exception {
 	data.setData(getBooleanMatrix(dataSetId));
     }
 
-    private static boolean[][] getBooleanMatrix(int dataSetId) throws NullPointerException, HDF5Exception {
+    /**
+     * getBooleanMatrix
+     * @param dataSetId the dataset ID to read.
+     * @return a boolean matrix
+     * @throws HDF5Exception .
+     */
+    private static boolean[][] getBooleanMatrix(int dataSetId) throws HDF5Exception {
 	int[] nbElems = H5Read.getAllDims(dataSetId); 
-	int[] data = new int[nbElems[0]* nbElems[1]];
+	int[] data = new int[nbElems[0] * nbElems[1]];
 	boolean[][] result = new boolean[(int) nbElems[0]][(int) nbElems[1]];
 	
 	H5.H5Dread_int(dataSetId, HDF5Constants.H5T_NATIVE_INT, H5.H5Dget_space(dataSetId), 
 		HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL, data);
 	
-	for(int i = 0 ; i < nbElems[0] ; ++i) {
-	    for (int j = 0 ; j < nbElems[1] ; ++j) {
-		result[i][j] = data[i + j * nbElems[0]] == 0 ? false : true;
+	for (int i = 0; i < nbElems[0]; ++i) {
+	    for (int j = 0; j < nbElems[1]; ++j) {
+		if (data[i + j * nbElems[0]] == 0) {
+		result[i][j] = false;
+		} else {
+		    result[i][j] = true;
+		}
 	    }
 	}
 	
