@@ -39,6 +39,8 @@ import org.xml.sax.SAXException;
 import org.scilab.forge.jlatexmath.fop.JLaTeXMathElementMapping;
 import org.scilab.forge.jlatexmath.fop.JLaTeXMathXMLHandler;
 
+import org.scilab.modules.commons.xml.ScilabTransformerFactory;
+
 /**
  * This class manages the build of the PDF file
  */
@@ -72,7 +74,7 @@ public final class BuildPDF {
 		}
 
 		try {
-                    FopFactory fopFactory = FopFactory.newInstance();
+                        FopFactory fopFactory = FopFactory.newInstance();
                         fopFactory.addElementMapping(new JLaTeXMathElementMapping());
                         fopFactory.getXMLHandlerRegistry().addXMLHandler(new JLaTeXMathXMLHandler());
                         fopFactory.setUserConfig(new File(System.getenv("SCI") + "/modules/helptools/etc/fopconf.xml"));
@@ -87,6 +89,7 @@ public final class BuildPDF {
 			}
 
 			// Step 4: Setup JAXP using identity transformer
+			String factoryName = ScilabTransformerFactory.useDefaultTransformerFactoryImpl();
 			TransformerFactory factory = TransformerFactory.newInstance();
 			Transformer transformer = factory.newTransformer(); // identity transformer
 			// Step 5: Setup input and output for XSLT transformation 
@@ -98,8 +101,10 @@ public final class BuildPDF {
             
 			// Step 6: Start XSLT transformation and FOP processing
 			transformer.transform(src, res);
-            FormattingResults foResults = fop.getResults();
-            System.out.println("Generated " + foResults.getPageCount() + " pages in total.");
+			ScilabTransformerFactory.restoreTransformerFactoryImpl(factoryName);
+
+			FormattingResults foResults = fop.getResults();
+			System.out.println("Generated " + foResults.getPageCount() + " pages in total.");
 
 			//Clean-up
 			out.close();
@@ -119,5 +124,4 @@ public final class BuildPDF {
 			
 		return fileName;
 	}
-
 }
