@@ -19,7 +19,7 @@
 #include "localization.h"
 #include "freeArrayOfString.h"
 /*--------------------------------------------------------------------------*/
-int C2F(sci_addhistory)(char *fname,unsigned long fname_len)
+int sci_addhistory(char *fname,unsigned long fname_len)
 {
 	static int n1,m1;
 
