@@ -15,7 +15,8 @@
 #include "callFunctionFromGateway.h"
 #include "stack-c.h"
 /*--------------------------------------------------------------------------*/
-static gw_generic_table Tab[]={ 
+static gw_generic_table Tab[] = 
+{ 
   {intsplin,           "splin"},
   {intlsq_splin,       "lsq_splin"},
   {intinterp1,          "interp"},
@@ -32,7 +33,7 @@ static gw_generic_table Tab[]={
 int gw_interpolation(void)
 {
 	Rhs = Max(0, Rhs);
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab,SIZE_CURRENT_GENERIC_TABLE(Tab));
 	return 0;
 }
 /*--------------------------------------------------------------------------*/
