@@ -14,7 +14,7 @@
 #include "stack-c.h"
 #include "getpidc.h"
 /*--------------------------------------------------------------------------*/
-int C2F(sci_getpid)(char *fname,unsigned long fname_len)
+int sci_getpid(char *fname,unsigned long fname_len)
 {
 	int one = 1;
 	int l1 = 0;
