@@ -12,9 +12,8 @@
 
 #include "gw_io.h"
 /*--------------------------------------------------------------------------*/
-int C2F(sci_unix)(char *fname,unsigned long fname_len)
+int sci_unix(char *fname,unsigned long fname_len)
 {
-	C2F(sci_host) (fname,fname_len);
-	return 0;
+	return sci_host (fname,fname_len);
 }
 /*--------------------------------------------------------------------------*/
