@@ -12,7 +12,9 @@
 
 #include "gw_io.h"
 /*--------------------------------------------------------------------------*/
-int C2F(sci_writb)(char *fname,unsigned long fname_len)
+extern int C2F(intwritb)(); /* fortran subroutine */
+/*--------------------------------------------------------------------------*/
+int sci_writb(char *fname,unsigned long fname_len)
 {
 	C2F(intwritb)();
 	return 0;
