@@ -14,14 +14,15 @@
 #ifndef __LOADONUSECLASSPATH_H__
 #define __LOADONUSECLASSPATH_H__
 
-#include "machine.h" /* BOOL */
+#include "dynlib_jvm.h"
+#include "BOOL.h" /* BOOL */
 
 /**
 * Load a serie of jar(s) matching to the tag declared in etc/classpath.xml
 * @param a new path to add
 * @return TRUE or FALSE
 */
-BOOL loadOnUseClassPath(char *tag);
+JVM_IMPEXP BOOL loadOnUseClassPath(char *tag);
 
 #endif /* __LOADONUSECLASSPATH_H__ */
 /*--------------------------------------------------------------------------*/ 
