@@ -17,7 +17,8 @@
 #include "callFunctionFromGateway.h"
 #include "stack-c.h"
 /*--------------------------------------------------------------------------*/ 
-static gw_generic_table Tab[]={
+static gw_generic_table Tab[] = 
+{
 	{C2F(intqr),"qr"},
 	{C2F(intsvd),"svd"},
 	{C2F(intlsq),"lsq"},
@@ -31,13 +32,13 @@ static gw_generic_table Tab[]={
 	{C2F(intschur),"schur"},
 	{C2F(inthess),"hess"},
 	{C2F(intdet),"det"},
-	{C2F(intbalanc),"balanc"},
+	{C2F(intbalanc),"balanc"}
 };
 /*--------------------------------------------------------------------------*/ 
 int gw_linear_algebra2(void)
 {  
 	Rhs = Max(0, Rhs);
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 	if (Err <= 0 && C2F(errgst).err1 <= 0) C2F(putlhsvar)();
 	return 0;
 }
