@@ -1,6 +1,7 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2008 - INRIA - Vincent COUVERT 
+ * Copyright (C) 2010 - DIGITEO - Yann COLLETTE 
  * 
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
@@ -15,7 +16,6 @@
 
 #include "matfile_manager.h"
 #include "MALLOC.h"
-#include "stack-c.h" /* stack-def.h, stack1.h, stack2.h, stack3.h included */
 #include "localization.h"
 #include "Scierror.h"
 #include "sciprint.h"
@@ -25,98 +25,116 @@
  * This function write nothing on stack but calls the function which 
  * does the work according to Matlab Variable type
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateMatlabVariable(int stkPos, matvar_t *matVariable);
+int CreateMatlabVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 
 /*
  * Create a Scilab Integer variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param integerType Scilab int type (See stack-c.h)
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateIntegerVariable(int stkPos, int integerType, matvar_t *matVariable);
+int CreateIntegerVariable(int iVar, int integerType, matvar_t *matVariable, int * parent, int item_position);
 
 /*
  * Create a Scilab HyperMatrix variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param type contents data type
  * @param iscomplex TRUE if the variable is Complex
  * @param rank number of dimensions of the variable
  * @param dims variable dimensions
  * @param realdata pointer to real data
  * @param complexdata pointer to complex data
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateHyperMatrixVariable(int stkPos, const char *type, int *iscomplex, int * rank, int *dims, double *realdata, double *complexdata);
+int CreateHyperMatrixVariable(int iVar, const char *type, int *iscomplex, int * rank, int *dims, double *realdata, double *complexdata, int * parent, int item_position);
 
 /*
  * Create a Scilab Struct variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateStructVariable(int stkPos, matvar_t *matVariable);
+int CreateStructVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 /*
  * Create a Scilab Cell variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateCellVariable(int stkPos, matvar_t *matVariable);
+int CreateCellVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 /*
  * Create a Scilab Char variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateCharVariable(int stkPos, matvar_t *matVariable);
+int CreateCharVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 /*
  * Create a Scilab Sparse variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateSparseVariable(int stkPos, matvar_t *matVariable);
+int CreateSparseVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 /*
  * Create a Scilab Double variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateDoubleVariable(int stkPos, matvar_t *matVariable);
+int CreateDoubleVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 /*
  * Create a Scilab Boolean variable on stack from a Matlab variable
  * 
- * @param stkPos position on the stack
+ * @param iVar position on the stack
  * @param matVariable Matlab variable (See MATIO library)
+ * @param parent parent mlist. If NULL, a normal variable is created.
+ * @parem item_position position of the variable in the mlist. Only effective if parent !=NULL
  *
  * @return TRUE if the variable has been written without problem
  */
-int CreateBooleanVariable(int stkPos, matvar_t *matVariable);
+int CreateBooleanVariable(int iVar, matvar_t *matVariable, int * parent, int item_position);
 
 #endif /* !__CREATEMATLABVARIABLE_H__ */
