@@ -1,6 +1,7 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2008 - INRIA - Vincent COUVERT 
+ * Copyright (C) 2010 - DIGITEO - Yann COLLETTE
  * 
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
@@ -11,16 +12,23 @@
  */
 
 #include "CreateMatlabVariable.h"
+#include "stack-c.h"
+#include "api_scilab.h"
+
+#define MATIO_ERROR if(_SciErr.iErr) \
+    {				     \
+      printError(&_SciErr, 0);	     \
+      return 0;			     \
+    }
 
 /* Defined in SCI/modules/sparse/src/fortran/spt.f */
 extern int C2F(spt)(int *m, int *n, int *nel, int *it, int *workArray, 
-             double *A_R, double *A_I, int *A_mnel, int *A_icol,
-             double *At_R, double *At_I, int *At_mnel, int *At_icol);
-
-int CreateSparseVariable(int stkPos, matvar_t *matVariable)
+		    double *A_R, double *A_I, int *A_mnel, int *A_icol,
+		    double *At_R, double *At_I, int *At_mnel, int *At_icol);
+		   
+int CreateSparseVariable(int iVar, matvar_t *matVariable, int * parent, int item_position)
 {
   int K = 0;
-  
   sparse_t *sparseData = NULL;
   SciSparse *scilabSparse = NULL;
   SciSparse *scilabSparseT = NULL; /* Transpose */
@@ -28,7 +36,8 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
   int *rowIndexes = NULL;
   int *workArray = NULL;
   struct ComplexSplit *complexData = NULL;
-  
+  SciErr _SciErr;
+
   sparseData = (sparse_t*) matVariable->data;
 
   scilabSparse = (SciSparse*) MALLOC(sizeof(SciSparse));
@@ -36,7 +45,7 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
     {
       Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
       return FALSE;
-    };
+    }
 
   /* Computes column indexes from Matlab indexes */
   if (sparseData->njc > 1)
@@ -46,13 +55,14 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
         {
           Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
           return FALSE;
-        };
+        }
       
       for (K=0; K<sparseData->njc-1; K++)
         {
           colIndexes[K] = sparseData->jc[K+1] - sparseData->jc[K];
         }
     }
+
   /* Computes row indexes from Matlab indexes */
   rowIndexes = (int*) MALLOC(sizeof(int) * sparseData->nir);
   if (rowIndexes==NULL)
@@ -67,12 +77,13 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
     }
 
   /* Create sparse matrix to be transposed */
-  scilabSparse->m = matVariable->dims[1];
-  scilabSparse->n = matVariable->dims[0];
-  scilabSparse->it = matVariable->isComplex;
-  scilabSparse->nel = sparseData->ndata;
+  scilabSparse->m    = matVariable->dims[1];
+  scilabSparse->n    = matVariable->dims[0];
+  scilabSparse->it   = matVariable->isComplex;
+  scilabSparse->nel  = sparseData->ndata;
   scilabSparse->mnel = colIndexes;
   scilabSparse->icol = rowIndexes;
+
   if (scilabSparse->it == 0)
     {
       scilabSparse->R = (double*) sparseData->data;
@@ -91,11 +102,13 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
     {
       Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
       return FALSE;
-    };
-  scilabSparseT->m = scilabSparse->n;
-  scilabSparseT->n = scilabSparse->m;
-  scilabSparseT->it = scilabSparse->it;
-  scilabSparseT->nel =  scilabSparse->nel;
+    }
+
+  scilabSparseT->m   = scilabSparse->n;
+  scilabSparseT->n   = scilabSparse->m;
+  scilabSparseT->it  = scilabSparse->it;
+  scilabSparseT->nel = scilabSparse->nel;
+
   if (scilabSparseT->m == 0)
     {
       workArray = (int*) MALLOC(sizeof(int));
@@ -104,35 +117,40 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
     {
       workArray = (int*) MALLOC(sizeof(int) * scilabSparseT->m);
     }
+
   if (workArray==NULL)
     {
       Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
       return FALSE;
     }
+
   if (scilabSparseT->m != 0) {
-  scilabSparseT->mnel = (int*) MALLOC(sizeof(int) * scilabSparseT->m); 
-  if (scilabSparseT->mnel==NULL)
-    {
-      Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
-      return FALSE;
-    };
+    scilabSparseT->mnel = (int*) MALLOC(sizeof(int) * scilabSparseT->m); 
+    if (scilabSparseT->mnel==NULL)
+      {
+	Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
+	return FALSE;
+      }
   }
+
   if (scilabSparseT->nel != 0) {
-  scilabSparseT->icol = (int*) MALLOC(sizeof(int) * scilabSparseT->nel); 
-  if (scilabSparseT->icol==NULL)
-    {
-      Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
-      return FALSE;
-    };
+    scilabSparseT->icol = (int*) MALLOC(sizeof(int) * scilabSparseT->nel); 
+    if (scilabSparseT->icol==NULL)
+      {
+	Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
+	return FALSE;
+      }
   }
+
   if (scilabSparseT->nel != 0) {
-  scilabSparseT->R = (double*) MALLOC(sizeof(double) * scilabSparseT->nel); 
-  if (scilabSparseT->R==NULL)
-    {
-      Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
-      return FALSE;
-    };
+    scilabSparseT->R = (double*) MALLOC(sizeof(double) * scilabSparseT->nel); 
+    if (scilabSparseT->R==NULL)
+      {
+	Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
+	return FALSE;
+      }
   }
+
   if (scilabSparseT->it)
     {
       scilabSparseT->I = (double*) MALLOC(sizeof(double) * scilabSparseT->nel);
@@ -140,52 +158,52 @@ int CreateSparseVariable(int stkPos, matvar_t *matVariable)
         {
           Scierror(999, _("%s: No more memory.\n"), "CreateSparseVariable");
           return FALSE;
-        };
+        }
     }
-
+  
   C2F(spt)(&scilabSparse->m, &scilabSparse->n, &scilabSparse->nel, &scilabSparse->it, workArray, 
-             scilabSparse->R, scilabSparse->I, scilabSparse->mnel, scilabSparse->icol,
-             scilabSparseT->R, scilabSparseT->I, scilabSparseT->mnel, scilabSparseT->icol);
+	   scilabSparse->R, scilabSparse->I, scilabSparse->mnel, scilabSparse->icol,
+	   scilabSparseT->R, scilabSparseT->I, scilabSparseT->mnel, scilabSparseT->icol);
 
-  CreateVarFromPtr(stkPos, SPARSE_MATRIX_DATATYPE, &scilabSparseT->m, &scilabSparseT->n, scilabSparseT);
+  if (scilabSparse->it)
+    {
+      if (parent==NULL)
+	{
+	  _SciErr = createComplexSparseMatrix(pvApiCtx, iVar, scilabSparse->m, scilabSparse->n, scilabSparse->nel,
+					      scilabSparseT->mnel, scilabSparseT->icol, scilabSparseT->R, scilabSparseT->I);
+	}
+      else
+	{
+	  _SciErr = createComplexSparseMatrixInList(pvApiCtx, iVar, parent, item_position,
+						    scilabSparse->m, scilabSparse->n, scilabSparse->nel,
+						    scilabSparseT->mnel, scilabSparseT->icol, scilabSparseT->R, scilabSparseT->I);
+	}
+    }
+  else
+    {
+      if (parent==NULL)
+	{
+	  _SciErr = createSparseMatrix(pvApiCtx, iVar, scilabSparseT->m, scilabSparseT->n, scilabSparseT->nel,
+				       scilabSparseT->mnel, scilabSparseT->icol, scilabSparseT->R);
+	}
+      else
+	{
+	  _SciErr = createSparseMatrixInList(pvApiCtx, iVar, parent, item_position, 
+					     scilabSparseT->m, scilabSparseT->n, scilabSparseT->nel,
+					     scilabSparseT->mnel, scilabSparseT->icol, scilabSparseT->R);
+	}
+    }
 
   /* Free all arrays */
-  if (scilabSparse != NULL)
-    {
-      FREE(scilabSparse);
-    }
-  if (colIndexes != NULL) 
-    {
-      FREE(colIndexes);
-    }
-  if (rowIndexes != NULL)
-    {
-      FREE(rowIndexes);
-    }
-  if (workArray != NULL)
-    {
-      FREE(workArray);
-    }
-  if (scilabSparseT->m != 0)
-    {
-      FREE(scilabSparseT->mnel);
-    }
-  if (scilabSparseT->nel != 0)
-    {
-      FREE(scilabSparseT->icol);
-    }
-  if (scilabSparseT->nel != 0)
-    {
-      FREE(scilabSparseT->R);
-    }
-  if ((scilabSparseT->nel != 0) && (scilabSparseT->it != 0))
-    {
-      FREE(scilabSparseT->I);
-    }
-  if (scilabSparseT != NULL)
-    {
-      FREE(scilabSparseT);
-    }
+  if (scilabSparse != NULL)    FREE(scilabSparse);
+  if (colIndexes != NULL)      FREE(colIndexes);
+  if (rowIndexes != NULL)      FREE(rowIndexes);
+  if (workArray != NULL)       FREE(workArray);
+  if (scilabSparseT->m != 0)   FREE(scilabSparseT->mnel);
+  if (scilabSparseT->nel != 0) FREE(scilabSparseT->icol);
+  if (scilabSparseT->nel != 0) FREE(scilabSparseT->R);
+  if ((scilabSparseT->nel != 0) && (scilabSparseT->it != 0)) FREE(scilabSparseT->I);
+  if (scilabSparseT != NULL)   FREE(scilabSparseT);
   
   return TRUE;
 }
