@@ -95,7 +95,7 @@ int sci_qld(char *fname,unsigned long fname_len)
 	if ((*istk(me)<0) || (*istk(me)>n))
 	{
 		Err = 7;
-		Error(116);
+		SciError(116);
 		return 0;
 	}
 
