@@ -25,4 +25,14 @@
  */
 OUTPUT_STREAM_IMPEXP int C2F(msgs)(int *n, int *ierr);
 
+
+/**
+* @TODO : add comment
+*
+* @param n 
+* @param ierr  
+*/
+OUTPUT_STREAM_IMPEXP void Msgs(int n,int ierr);
+
+
 #endif /* __MSGS_H__ */
