@@ -14,7 +14,7 @@
 #define __INTMATPVM__
 /*--------------------------------------------------------------------------*/ 
 #include "dynlib_pvm.h"
-#include "api_scilab.h"
+#include "stack-c.h"
 /*--------------------------------------------------------------------------*/ 
 PVM_IMPEXP int gw_pvm(void);
 /*--------------------------------------------------------------------------*/ 
