@@ -15,7 +15,6 @@
 /* Allan CORNET */
 /*--------------------------------------------------------------------------*/ 
 #include "gw_pvm.h"
-#include "with_pvm.h"
 #include "localization.h"
 #include "Scierror.h"
 /*--------------------------------------------------------------------------*/ 
@@ -29,14 +28,3 @@ int gw_pvm(void)
 	return 0;
 }
 /*--------------------------------------------------------------------------*/ 
-int C2F(withpvm)(int *rep)
-{ 
-	*rep =0; 
-	return 0;
-}
-/*--------------------------------------------------------------------------*/ 
-BOOL withpvm(void)
-{
-	return FALSE;
-}
-/*--------------------------------------------------------------------------*/ 
