@@ -1,4 +1,9 @@
 /* 
+ * 
+ * Copyright (C) 2010 - DIGITEO - Michael Baudin
+ * Copyright (C) 2004 - Bruno Pincon
+ * Copyright (C) 1999 - G. Marsaglia
+ * 
  *   PURPOSE
  *      the kiss generator of G. Marsaglia
  *      generate random integers (uint) in [0, 2^32 - 1]
@@ -17,13 +22,12 @@
  *      they  are not interfaced at the scilab level.
  *
  *      Need that it is assumed that the 
- *         unsigned long arithmetic is the classic 32 bits 
+ *         unsigned int arithmetic is the classic 32 bits 
  *         unsigned arithmetic modulo 2^32 (ie all is exact
  *         modulo 2^32) 
  *
  * 	License: This code is released under public domain.
  * 	(Compatible with CeCILL)
-
  */
 #include <math.h>             /* to use floor    */
 
@@ -40,40 +44,40 @@
 #define KISS  ((MWC^CONG)+SHR3)
 
 /*  the kiss 's state  (any int in [0,2^32-1] are OK ?) */
-static unsigned long z=362436069, w=521288629, jsr=123456789, jcong=380116160;
+static unsigned int z=362436069, w=521288629, jsr=123456789, jcong=380116160;
 
-unsigned long kiss()
+unsigned int kiss()
 {
-  return ( KISS );
+    return ( KISS );
 }
 
 int set_state_kiss(double g1, double g2, double g3, double g4)
 {
-  if (g1 == floor(g1) && g2 == floor(g2) && 
-      g3 == floor(g3) && g4 == floor(g4) &&  
-      0.0 <= g1 && g1 <= 4294967295.0 &&
-      0.0 <= g2 && g2 <= 4294967295.0 &&
-      0.0 <= g3 && g3 <= 4294967295.0 &&
-      0.0 <= g4 && g4 <= 4294967295.0 )
+    if (g1 == floor(g1) && g2 == floor(g2) && 
+        g3 == floor(g3) && g4 == floor(g4) &&  
+        0.0 <= g1 && g1 <= 4294967295.0 &&
+        0.0 <= g2 && g2 <= 4294967295.0 &&
+        0.0 <= g3 && g3 <= 4294967295.0 &&
+        0.0 <= g4 && g4 <= 4294967295.0 )
     {
-          z = (unsigned long) g1;
-          w = (unsigned long) g2;
-        jsr = (unsigned long) g3;
-      jcong = (unsigned long) g4;
-      return ( 1 );
+        z = (unsigned int) g1;
+        w = (unsigned int) g2;
+        jsr = (unsigned int) g3;
+        jcong = (unsigned int) g4;
+        return ( 1 );
     }
-  else
+    else
     {
-      sciprint(_("Bad seeds for kiss, must be integers in [0,2^32-1]\n"));
-      return ( 0 );
+        sciprint(_("Bad seeds for kiss, must be integers in [0,2^32-1]\n"));
+        return ( 0 );
     }
 }
 
 void get_state_kiss(double g[])
 {
-  g[0] = (double) z;
-  g[1] = (double) w;
-  g[2] = (double) jsr;
-  g[3] = (double) jcong;
+    g[0] = (double) z;
+    g[1] = (double) w;
+    g[2] = (double) jsr;
+    g[3] = (double) jcong;
 }
 
