@@ -1,6 +1,7 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
- * Copyright (C) 2008 - INRIA - Jean-Baptiste Silvy 
+ * Copyright (C) 2008 - INRIA - Jean-Baptiste Silvy
+ * Copyright (C) 2009 - DIGITEO - Pierre Lando
  * desc : Class specialized in drawing ticks  
  * 
  * This file must be used under the terms of the CeCILL.
@@ -30,7 +31,7 @@ MiddleXAxisPositioner::~MiddleXAxisPositioner(void)
 void MiddleXAxisPositioner::getAxisBounds(double startBound[3], double endBound[3])
 {
   double zCoordinate = findUpperZCoordinate();
-  double yCoordinate = findMiddleYCoordinate(zCoordinate);
+  double yCoordinate = (m_dYmin + m_dYmax) / 2.0;
 
   startBound[0] = m_dXmin;
   startBound[1] = yCoordinate;
@@ -41,25 +42,5 @@ void MiddleXAxisPositioner::getAxisBounds(double startBound[3], double endBound[
   endBound[2] = zCoordinate;
 }
 /*------------------------------------------------------------------------------------------*/
-double MiddleXAxisPositioner::findMiddleYCoordinate(double zCoordinate)
-{
-  // find if 0 is in the range of Y coordinates
-  // if so then one of yMax or yMax is <= 0 and the other is not
-  if (m_dYmin * m_dYmax <= 0.0)
-  {
-    return 0.0;
-  }
-  else if (m_dYmax < 0.0)
-  {
-  // both bounds are negative
-  return m_dYmax;
-  }
-  else
-  {
-    // both bounds are positive
-    return m_dYmin;
-  }
-}
-/*------------------------------------------------------------------------------------------*/
 
 }
