@@ -23,11 +23,12 @@
 /* INRIA 2008 */
 /* Allan CORNET */
 /*--------------------------------------------------------------------------*/
+#include "machine.h" /* C2F */
 #include "gw_scicos.h"
 /*--------------------------------------------------------------------------*/
 extern int C2F(intvar2vec)(char *fname,unsigned long fname_len); /* fortran */
 /*--------------------------------------------------------------------------*/
-int C2F(sci_var2vec)(char *fname,unsigned long fname_len)
+int sci_var2vec(char *fname,unsigned long fname_len)
 {
 	C2F(intvar2vec)(fname,fname_len);
 	return 0;
