@@ -18,15 +18,15 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block.h"
+/*--------------------------------------------------------------------------*/
 #include "MALLOC.h"
-
-#ifndef NULL
-	#define NULL 0
-#endif
-#define SCICOS_FREE(x) if (x  != NULL) FREE((char *) x);
-
+#include "scicos_free.h"
+#include "scicos_block.h"
+/*--------------------------------------------------------------------------*/
+#define SCICOS_FREE(x) FREE((char *) x);
+/*--------------------------------------------------------------------------*/
 void scicos_free(void *p)
 {
   SCICOS_FREE(p);
 }
+/*--------------------------------------------------------------------------*/
