@@ -18,14 +18,18 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block4.h"
+/*--------------------------------------------------------------------------*/ 
 #include <math.h>
-
-void bit_clear_16(scicos_block *block,int flag)
+#include "scicos_block4.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void bit_clear_16(scicos_block *block,int flag)
 {
-  int m,n,i;
-  short *opar;
-  short *u,*y;
+  int m = 0,n = 0,i = 0;
+  short *opar = NULL;
+  short *u = NULL,*y = NULL;
+
   m=GetInPortRows(block,1);
   n=GetOutPortCols(block,1);
   opar=Getint16OparPtrs(block,1);
@@ -33,3 +37,4 @@ void bit_clear_16(scicos_block *block,int flag)
   y=Getint16OutPortPtrs(block,1);
   for (i=0;i<m*n;i++) y[i]=((u[i])&(*opar));
 }
+/*--------------------------------------------------------------------------*/ 
