@@ -18,6 +18,7 @@
  *
  * See the file ./license.txt
  */
+/*--------------------------------------------------------------------------*/ 
 /**
    \file canimxy3d.c
    \author Benoit Bayol
@@ -26,6 +27,7 @@
    \brief CANIMXY3D is a scope in 3D which draw its input as a XY scope, there is animation.
    \see CANIMXY3D.sci in macros/scicos_blocks/Sinks/
 */
+/*--------------------------------------------------------------------------*/ 
 #include "CurrentObjectsManagement.h"
 #include "scoMemoryScope.h"
 #include "scoWindowScope.h"
@@ -34,34 +36,39 @@
 #include "scoSetProperty.h"
 #include "scicos_block4.h"
 #include "DrawingBridge.h"
-
+#include "scicos_malloc.h"
+#include "scicos_free.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
 /** \fn canimxy3d_draw(scicos_block * block, ScopeMemory ** pScopeMemory, int firstdraw)
     \brief Function to draw or redraw the window
 */
-void canimxy3d_draw(scicos_block * block, ScopeMemory ** pScopeMemory, int firstdraw)
+SCICOS_BLOCKS_IMPEXP void canimxy3d_draw(scicos_block * block, ScopeMemory ** pScopeMemory, int firstdraw)
 {
-  int i; //As usual
-  int * ipar; //Integer Parameters
-  int color_number; //Flag on Color
-  int * color;
-  int * line_size;
-  int nbr_curves;
-  int animed;
-  int win; //Windows ID : To give a name to the window
-  int buffer_size; //Buffer Size
+  int i = 0; //As usual
+  int * ipar = NULL; //Integer Parameters
+  int color_number = 0; //Flag on Color
+  int * color = NULL;
+  int * line_size = NULL;
+  int nbr_curves = 0;
+  int animed = 0;
+  int win = 0; //Windows ID : To give a name to the window
+  int buffer_size = 0; //Buffer Size
   int win_pos[2]; //Position of the Window
   int win_dim[2]; //Dimension of the Window
-  int nipar;
-  double * rpar; //Reals parameters
-  double xmin, xmax, ymin, ymax, zmin, zmax,alpha,theta; //Ymin and Ymax are vectors here
+  int nipar = 0;
+  double * rpar = NULL; //Reals parameters
+  double xmin = 0., xmax = 0., ymin = 0., ymax = 0., zmin = 0., zmax = 0.,alpha = 0.,theta = 0.; //Ymin and Ymax are vectors here
   scoGraphicalObject Pinceau; //Pointer to each polyline of each axes
   scoGraphicalObject Gomme; //Pointer to each polyline of each axes
   scoGraphicalObject Trait; //Pointer to each trache of each axes
-  int number_of_subwin;
-  int number_of_curves_by_subwin;
+  int number_of_subwin = 0;
+  int number_of_curves_by_subwin = 0;
   int dimension = 3;
-  int gomme_color;
+  int gomme_color = 0;
   int size=0;
+  char *label = NULL;
 
   ipar = GetIparPtrs(block);
   nipar = GetNipar(block);
@@ -69,6 +76,8 @@ void canimxy3d_draw(scicos_block * block, ScopeMemory ** pScopeMemory, int first
   win = ipar[0];
   color_number = ipar[1];
   buffer_size = ipar[2];
+  label = GetLabelPtrs(block);
+
   color = (int*)scicos_malloc(color_number*sizeof(int));
   line_size = (int*)scicos_malloc(color_number*sizeof(int));
   for(i = 0 ; i < color_number ; i++)
@@ -188,22 +197,23 @@ void canimxy3d_draw(scicos_block * block, ScopeMemory ** pScopeMemory, int first
       pSUBWIN_FEATURE(scoGetPointerAxes(*pScopeMemory,0))->alpha = alpha;
       pSUBWIN_FEATURE(scoGetPointerAxes(*pScopeMemory,0))->theta = theta;
 
-      scoAddTitlesScope(*pScopeMemory,"x","y","z");
+      scoAddTitlesScope(*pScopeMemory,label,"x","y","z");
     }
   scicos_free(color);
   scicos_free(line_size);
 }
+/*--------------------------------------------------------------------------*/ 
 /** \fn void canimxy3d(scicos_block * block, int flag)
     \brief the computational function
     \param block A pointer to a scicos_block
     \param flag An int which indicates the state of the block (init, update, ending)
 */
-void canimxy3d(scicos_block * block, int flag)
+SCICOS_BLOCKS_IMPEXP void canimxy3d(scicos_block * block, int flag)
 {
   /* Declarations*/
-  double *u1,*u2,*u3;
-  int i;
-  ScopeMemory * pScopeMemory;
+  double *u1 = NULL,*u2 = NULL,*u3 = NULL;
+  int i = 0;
+  ScopeMemory * pScopeMemory = NULL;
   scoGraphicalObject pLongDraw;
   /* State Machine Control */
   switch(flag)
@@ -278,3 +288,4 @@ void canimxy3d(scicos_block * block, int flag)
  
     }
 }
+/*--------------------------------------------------------------------------*/ 
