@@ -18,17 +18,21 @@
 *
 * See the file ./license.txt
 */
-# include "scicos_block4.h"
-# include "machine.h"
-# include <math.h>
-# include <memory.h>
-extern int sciprint();
-
-void convert(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+#include <math.h>
+#include <memory.h>
+#include "scicos.h"
+#include "scicos_block4.h"
+#include "sciprint.h"
+#include "localization.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void convert(scicos_block *block,int flag)
 {
- int m,n,i;
- int *ipar;
- double v,w,k;
+ int m = 0,n = 0,i = 0;
+ int *ipar = NULL;
+ double v = 0.,w = 0.,k = 0.;
  
  m=GetInPortRows(block,1);
  n=GetInPortCols(block,1);
@@ -38,16 +42,17 @@ void convert(scicos_block *block,int flag)
     {
      switch (*ipar){
 	    case 1:{ 
-		   void *u,*y;
+		   void *u = NULL,*y = NULL;
 		   int so;
 		   so=GetSizeOfOut(block,1);
-     	  	   u=GetInPortPtrs(block,1);
-     	  	   y=GetOutPortPtrs(block,1);
-     	  	   memcpy(y,u,m*n*so);
-     	  	   break;}
+     	   u=GetInPortPtrs(block,1);
+     	   y=GetOutPortPtrs(block,1);
+     	   memcpy(y,u,m*n*so);
+     	  break;
+			   }
 	    case 2:{
-		   double *u;
-		   long *y;
+		   double *u = NULL;
+		   long *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   k=pow(2,32);
@@ -61,8 +66,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(long)w;}
 		   break;}
 	    case 3:{
-		   double *u;
-		   short *y;
+		   double *u = NULL;
+		   short *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -76,8 +81,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(short)w;}
 		   break;}
 	    case 4:{
-		   double *u;
-		   char *y;
+		   double *u = NULL;
+		   char *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -91,8 +96,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(char)w;}
 		   break;}
 	    case 5:{
-		   double *u;
-		   unsigned long *y;
+		   double *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   k=pow(2,32);
@@ -102,8 +107,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned long)w;}
 		   break;}
 	    case 6:{
-		   double *u;
-		   unsigned short *y;
+		   double *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -113,8 +118,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned short)w;}
 		   break;}
 	    case 7:{
-		   double *u;
-		   unsigned char *y;
+		   double *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -124,15 +129,15 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned char)w;}
 		   break;}
 	    case 8:{
-		   long *u;
-		   double *y;
+		   long *u = NULL;
+		   double *y = NULL;
 		   u=Getint32InPortPtrs(block,1);
 		   y=GetRealOutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) y[i]=(double) u[i];
 		   break;}
 	    case 9:{
-		   long *u;
-		   short *y;
+		   long *u = NULL;
+		   short *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -146,8 +151,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(short)w;}
 		   break;}
 	    case 10:{
-		   long *u;
-		   char *y;
+		   long *u = NULL;
+		   char *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -161,8 +166,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(char)w;}
 		   break;}
 	    case 11:{
-		   long *u;
-		   unsigned short *y;
+		   long *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -172,8 +177,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned short)w;}
 		   break;}
 	    case 12:{
-		   long *u;
-		   unsigned char *y;
+		   long *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -183,23 +188,23 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned char)w;}
 		   break;}
 	    case 13:{
-		   short *u;
-		   double *y;
+		   short *u = NULL;
+		   double *y = NULL;
 		   u=Getint16InPortPtrs(block,1);
 		   y=GetRealOutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) y[i]=(double) u[i];
 		   break;}
 	    case 14:{
-		   short *u;
-		   long *y;
+		   short *u = NULL;
+		   long *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(long)u[i];}
 		   break;}
 	    case 15:{
-		   short *u;
-		   char *y;
+		   short *u = NULL;
+		   char *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -213,16 +218,16 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(char)w;}
 		   break;}
 	    case 16:{
-		   short *u;
-		   unsigned long *y;
+		   short *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 17:{
-		   short *u;
-		   unsigned char *y;
+		   short *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -232,54 +237,54 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned char)w;}
 		   break;}
 	    case 18:{
-		   char *u;
-		   double *y;
+		   char *u = NULL;
+		   double *y = NULL;
 		   u=Getint8InPortPtrs(block,1);
 		   y=GetRealOutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) y[i]=(double) u[i];
 		   break;}
 	    case 19:{
-		   char *u;
-		   long *y;
+		   char *u = NULL;
+		   long *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(long)u[i];}
 		   break;}
 	    case 20:{
-		   char *u;
-		   short *y;
+		   char *u = NULL;
+		   short *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(short)u[i];}
 		   break;}
 	    case 21:{
-		   char *u;
-		   unsigned long *y;
+		   char *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 22:{
-		   char *u;
-		   unsigned short *y;
+		   char *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(unsigned short)u[i];}
 		   break;}
 	    case 23:{
-		   unsigned long *u;
-		   double *y;
+		   unsigned long *u = NULL;
+		   double *y = NULL;
 		   u=Getuint32InPortPtrs(block,1);
 		   y=GetRealOutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) y[i]=(double) u[i];
 		   break;}
 	    case 24:{
-		   unsigned long *u;
-		   short *y;
+		   unsigned long *u = NULL;
+		   short *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -292,8 +297,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(short)w;}
 		   break;}
 	    case 25:{
-		   unsigned long *u;
-		   char *y;
+		   unsigned long *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -306,8 +311,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(char)w;}
 		   break;}
 	    case 26:{
-		   unsigned long *u;
-		   unsigned short *y;
+		   unsigned long *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -317,8 +322,8 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned short)w;}
 		   break;}
 	    case 27:{
-		   unsigned long *u;
-		   unsigned char *y;
+		   unsigned long *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -328,23 +333,23 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned char)w;}
 		   break;}
 	    case 28:{
-		   unsigned short *u;
-		   double *y;
+		   unsigned short *u = NULL;
+		   double *y = NULL;
 		   u=Getuint16InPortPtrs(block,1);
 		   y=GetRealOutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) y[i]=(double) u[i];
 		   break;}
 	    case 29:{
-		   unsigned short *u;
-		   long *y;
+		   unsigned short *u = NULL;
+		   long *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(long)u[i];}
 		   break;}
 	    case 30:{
-		   unsigned short *u;
-		   char *y;
+		   unsigned short *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -357,16 +362,16 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(char)w;}
 		   break;}
 	    case 31:{
-		   unsigned short *u;
-		   unsigned long *y;
+		   unsigned short *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 32:{
-		   unsigned short *u;
-		   unsigned char *y;
+		   unsigned short *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -376,47 +381,47 @@ void convert(scicos_block *block,int flag)
 		         y[i]=(unsigned char)w;}
 		   break;}
 	    case 33:{
-		   unsigned char *u;
-		   double *y;
+		   unsigned char *u = NULL;
+		   double *y = NULL;
 		   u=Getuint8InPortPtrs(block,1);
 		   y=GetRealOutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) y[i]=(double) u[i];
 		   break;}
 	    case 34:{
-		   unsigned char *u;
-		   long *y;
+		   unsigned char *u = NULL;
+		   long *y = NULL;
 	  	   u=Getuint8InPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(long)u[i];}
 		   break;}
 	    case 35:{
-		   unsigned char *u;
-		   short *y;
+		   unsigned char *u = NULL;
+		   short *y = NULL;
 	  	   u=Getuint8InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(short)u[i];}
 		   break;}
 	    case 36:{
-		   unsigned char *u;
-		   unsigned long *y;
+		   unsigned char *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getuint8InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 37:{
-		   unsigned char *u;
-		   unsigned short *y;
+		   unsigned char *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getuint8InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {y[i]=(unsigned short)u[i];}
 		   break;}
 	    case 38:{
-		   double *u;
-		   long *y;
+		   double *u = NULL;
+		   long *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   k=pow(2,32);
@@ -429,8 +434,8 @@ void convert(scicos_block *block,int flag)
 		       }
 		   break;}
 	    case 39:{
-		   double *u;
-		   short *y;
+		   double *u = NULL;
+		   short *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -443,8 +448,8 @@ void convert(scicos_block *block,int flag)
 		       }
 		   break;}
 	    case 40:{
-		   double *u;
-		   char *y;
+		   double *u = NULL;
+		   char *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -457,8 +462,8 @@ void convert(scicos_block *block,int flag)
 		       }
 		   break;}
 	    case 41:{
-		   double *u;
-		   unsigned long *y;
+		   double *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   k=pow(2,32);
@@ -471,8 +476,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 42:{
-		   double *u;
-		   unsigned short *y;
+		   double *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -485,8 +490,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 43:{
-		   double *u;
-		   unsigned char *y;
+		   double *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -499,8 +504,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 44:{
-		   long *u;
-		   short *y;
+		   long *u = NULL;
+		   short *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -513,8 +518,8 @@ void convert(scicos_block *block,int flag)
 		       }
 		   break;}
 	    case 45:{
-		   long *u;
-		   char *y;
+		   long *u = NULL;
+		   char *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -527,8 +532,8 @@ void convert(scicos_block *block,int flag)
 		       }
 		   break;}
 	    case 46:{
-		   long *u;
-		   unsigned long *y;
+		   long *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
@@ -538,8 +543,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 47:{
-		   long *u;
-		   unsigned short *y;
+		   long *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -552,8 +557,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 48:{
-		   long *u;
-		   unsigned char *y;
+		   long *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -566,8 +571,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 49:{
-		   short *u;
-		   char *y;
+		   short *u = NULL;
+		   char *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -580,8 +585,8 @@ void convert(scicos_block *block,int flag)
 		       }
 		   break;}
 	    case 50:{
-		   short *u;
-		   unsigned long *y;
+		   short *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
@@ -589,8 +594,8 @@ void convert(scicos_block *block,int flag)
 			 else y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 51:{
-		   short *u;
-		   unsigned short *y;
+		   short *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
@@ -600,8 +605,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 52:{
-		   short *u;
-		   unsigned char *y;
+		   short *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -614,8 +619,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 53:{
-		   char *u;
-		   unsigned long *y;
+		   char *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
@@ -623,8 +628,8 @@ void convert(scicos_block *block,int flag)
 			 else y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 54:{
-		   char *u;
-		   unsigned short *y;
+		   char *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
@@ -634,8 +639,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 55:{
-		   char *u;
-		   unsigned char *y;
+		   char *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
@@ -645,8 +650,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 56:{
-		   long *y;
-		   unsigned long *u;
+		   long *y = NULL;
+		   unsigned long *u = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   k=pow(2,32);
@@ -657,8 +662,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 57:{
-		   unsigned long *u;
-		   short *y;
+		   unsigned long *u = NULL;
+		   short *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -669,8 +674,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 58:{
-		   unsigned long *u;
-		   char *y;
+		   unsigned long *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -681,8 +686,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 59:{
-		   unsigned long *u;
-		   unsigned short *y;
+		   unsigned long *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -693,8 +698,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 60:{
-		   unsigned long *u;
-		   unsigned char *y;
+		   unsigned long *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -705,8 +710,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 61:{
-		   unsigned short *u;
-		   short *y;
+		   unsigned short *u = NULL;
+		   short *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
@@ -717,8 +722,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 62:{
-		   unsigned short *u;
-		   char *y;
+		   unsigned short *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -729,8 +734,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 63:{
-		   unsigned short *u;
-		   unsigned char *y;
+		   unsigned short *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -741,8 +746,8 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 64:{
-		   unsigned char *u;
-		   char *y;
+		   unsigned char *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint8InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
@@ -753,397 +758,397 @@ void convert(scicos_block *block,int flag)
 		   	}
 		   break;}
 	    case 65:{
-		   double *u;
-		   long *y;
+		   double *u = NULL;
+		   long *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   k=pow(2,32);
 		   for (i=0;i<m*n;i++)
 		   {if ((u[i]>k/2-1) | (u[i]<-(k/2)))
 		           {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		        else {y[i]=(long)(u[i]);}
 		       }
 		   break;}
 	    case 66:{
-		   double *u;
-		   short *y;
+		   double *u = NULL;
+		   short *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>k/2-1) | (u[i]<-(k/2)))
 		           {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		        else {y[i]=(short)(u[i]);}
 		       }
 		   break;}
 	    case 67:{
-		   double *u;
-		   char *y;
+		   double *u = NULL;
+		   char *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>k/2-1) | (u[i]<-(k/2)))
 		           {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		        else {y[i]=(char)(u[i]);}
 		       }
 		   break;}
 	    case 68:{
-		   double *u;
-		   unsigned long *y;
+		   double *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   k=pow(2,32);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>=k) | (u[i]<0))
 		           {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned long)(u[i]);}
 		   	}
 		   break;}
 	    case 69:{
-		   double *u;
-		   unsigned short *y;
+		   double *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>=k) | (u[i]<0))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned short)(u[i]);}
 		   	}
 		   break;}
 	    case 70:{
-		   double *u;
-		   unsigned char *y;
+		   double *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=GetRealInPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>=k) | (u[i]<0))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned char)(u[i]);}
 		   	}
 		   break;}
 	    case 71:{
-		   long *u;
-		   short *y;
+		   long *u = NULL;
+		   short *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>k/2-1) | (u[i]<-(k/2)))
 		            {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		        else {y[i]=(short)(u[i]);}
 		       }
 		   break;}
 	    case 72:{
-		   long *u;
-		   char *y;
+		   long *u = NULL;
+		   char *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>k/2-1) | (u[i]<-(k/2)))
 		            {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		        else {y[i]=(char)(u[i]);}
 		       }
 		   break;}
 	    case 73:{
-		   long *u;
-		   unsigned long *y;
+		   long *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		   	{if (u[i]<0)
 			    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned long)(u[i]);}
 		   	}
 		   break;}
 	    case 74:{
-		   long *u;
-		   unsigned short *y;
+		   long *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>=k) | (u[i]<0))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned short)(u[i]);}
 		   	}
 		   break;}
 	    case 75:{
-		   long *u;
-		   unsigned char *y;
+		   long *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint32InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>=k) | (u[i]<0))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned char)(u[i]);}
 		   	}
 		   break;}
 	    case 76:{
-		   short *u;
-		   char *y;
+		   short *u = NULL;
+		   char *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if ((u[i]>k/2-1) | (u[i]<-(k/2)))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		        else {y[i]=(char)(u[i]);}
 		       }
 		   break;}
 	    case 77:{
-		   short *u;
-		   unsigned long *y;
+		   short *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]<0)  
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 			 else y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 78:{
-		   short *u;
-		   unsigned short *y;
+		   short *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		   	{if (u[i]<0)
 			    {if (flag==1) 
-                                {sciprint("overflow error");
+                                {sciprint(_("overflow error"));
 			         set_block_error(-4);
 			         return;}}
 		   	else {y[i]=(unsigned short)(u[i]);}
 		   	}
 		   break;}
 	    case 79:{
-		   short *u;
-		   unsigned char *y;
+		   short *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint16InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if (((u[i]>=k) | (u[i]<0))& (flag==1))
 		       	    {if (flag==1) 
-                                 {sciprint("overflow error");
+                                 {sciprint(_("overflow error"));
 			          set_block_error(-4);
 			          return;}}
 		   	else {y[i]=(unsigned char)(u[i]);}
 		   	}
 		   break;}
 	    case 80:{
-		   char *u;
-		   unsigned long *y;
+		   char *u = NULL;
+		   unsigned long *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint32OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 			{if (u[i]<0)
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 			 else y[i]=(unsigned long)u[i];}
 		   break;}
 	    case 81:{
-		   char *u;
-		   unsigned short *y;
+		   char *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint16OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]<0)
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned short)(u[i]);}
 		   	}
 		   break;}
 	    case 82:{
-		   char *u;
-		   unsigned char *y;
+		   char *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getint8InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   for (i=0;i<m*n;i++) 
 		   	{if (u[i]<0)
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned char)(u[i]);}
 		   	}
 		   break;}
 	    case 83:{
-		   long *y;
-		   unsigned long *u;
+		   long *y = NULL;
+		   unsigned long *u = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint32OutPortPtrs(block,1);
 		   k=pow(2,32);
 		   for (i=0;i<m*n;i++) 
 		   	{if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(long)(u[i]);}
 		   	}
 		   break;}
 	    case 84:{
-		   unsigned long *u;
-		   short *y;
+		   unsigned long *u = NULL;
+		   short *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(short)(u[i]);}
 		   	}
 		   break;}
 	    case 85:{
-		   unsigned long *u;
-		   char *y;
+		   unsigned long *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(char)(u[i]);}
 		   	}
 		   break;}
 	    case 86:{
-		   unsigned long *u;
-		   unsigned short *y;
+		   unsigned long *u = NULL;
+		   unsigned short *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
-	           y=Getuint16OutPortPtrs(block,1);
+	       y=Getuint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned short)(u[i]);}
 		   	}
 		   break;}
 	    case 87:{
-		   unsigned long *u;
-		   unsigned char *y;
+		   unsigned long *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getuint32InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned char)(u[i]);}
 		   	}
 		   break;}
 	    case 88:{
-		   unsigned short *u;
-		   short *y;
+		   unsigned short *u = NULL;
+		   short *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getint16OutPortPtrs(block,1);
 		   k=pow(2,16);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(short)(u[i]);}
 		   	}
 		   break;}
 	    case 89:{
-		   unsigned short *u;
-		   char *y;
+		   unsigned short *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(char)(u[i]);}
 		   	}
 		   break;}
 	    case 90:{
-		   unsigned short *u;
-		   unsigned char *y;
+		   unsigned short *u = NULL;
+		   unsigned char *y = NULL;
 	  	   u=Getuint16InPortPtrs(block,1);
 	           y=Getuint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(unsigned char)(u[i]);}
 		   	}
 		   break;}
 	    case 91:{
-		   unsigned char *u;
-		   char *y;
+		   unsigned char *u = NULL;
+		   char *y = NULL;
 	  	   u=Getuint8InPortPtrs(block,1);
 	           y=Getint8OutPortPtrs(block,1);
 		   k=pow(2,8);
 		   for (i=0;i<m*n;i++) 
 		        {if (u[i]>(k/2-1))
 		       	    {if (flag==1)
-                               {sciprint("overflow error");
+                               {sciprint(_("overflow error"));
 			        set_block_error(-4);
 			        return;}}
 		   	else {y[i]=(char)(u[i]);}
@@ -1152,3 +1157,4 @@ void convert(scicos_block *block,int flag)
 	   }
 	}
  }
+/*--------------------------------------------------------------------------*/ 
