@@ -18,15 +18,18 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-void cumsumz_m(scicos_block *block,int flag)
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void cumsumz_m(scicos_block *block,int flag)
 {
-  double *ur;
-  double *ui;
-  double *yr;
-  double *yi;
-  int nu,mu,j;
+  double *ur = NULL;
+  double *ui = NULL;
+  double *yr = NULL;
+  double *yi = NULL;
+  int nu = 0,mu = 0,j = 0;
   mu=GetInPortRows(block,1);
   nu=GetInPortCols(block,1);
   ur=GetRealInPortPtrs(block,1);
@@ -36,6 +39,9 @@ void cumsumz_m(scicos_block *block,int flag)
   yr[0]=ur[0];
   yi[0]=ui[0];
   for(j=1;j<mu*nu;j++)
-       {yr[j]=ur[j]+yr[j-1];
-       yi[j]=ui[j]+yi[j-1];}
+  {
+	  yr[j]=ur[j]+yr[j-1];
+      yi[j]=ui[j]+yi[j-1];
+  }
 }
+/*--------------------------------------------------------------------------*/ 
