@@ -18,15 +18,19 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-void cumsumz_r(scicos_block *block,int flag)
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void cumsumz_r(scicos_block *block,int flag)
 {
-  double *ur;
-  double *ui;
-  double *yr;
-  double *yi;
-  int nu,mu,i,j,ij;
+  double *ur = NULL;
+  double *ui = NULL;
+  double *yr = NULL;
+  double *yi = NULL;
+  int nu = 0,mu = 0,i = 0,j = 0,ij = 0;
+
   mu=GetInPortRows(block,1);
   nu=GetInPortCols(block,1);
   ur=GetRealInPortPtrs(block,1);
@@ -43,3 +47,4 @@ void cumsumz_r(scicos_block *block,int flag)
 	    yr[ij]=ur[ij]+yr[ij-1];
 	    yi[ij]=ui[ij]+yi[ij-1];}}
 }
+/*--------------------------------------------------------------------------*/ 
