@@ -18,18 +18,21 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-void delay4_i32(scicos_block *block,int flag)
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void delay4_i32(scicos_block *block,int flag)
 {
   /* Copyright INRIA
    
      Scicos block simulator
      Ouputs nx*dt delayed input */
 
-  long *y,*u,*oz;
-  int nz,mz;
-  int i;
+  long *y = NULL,*u = NULL,*oz = NULL;
+  int nz = 0,mz = 0;
+  
   
   u=Getint32InPortPtrs(block,1);
   y=Getint32OutPortPtrs(block,1);
@@ -41,6 +44,7 @@ void delay4_i32(scicos_block *block,int flag)
     y[0]=oz[0];
   }else if (flag == 2){
     /*  shift buffer */
+	int i = 0; 
     for (i=0; i<=(mz*nz)-2; i++){
       oz[i]=oz[i+1];
     }
@@ -48,3 +52,4 @@ void delay4_i32(scicos_block *block,int flag)
     oz[(mz*nz)-1]=u[0];
   }
 }
+/*--------------------------------------------------------------------------*/ 
