@@ -18,19 +18,20 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-void delay4_i8(scicos_block *block,int flag)
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void delay4_i8(scicos_block *block,int flag)
 {
   /* Copyright INRIA
    
      Scicos block simulator
      Ouputs nx*dt delayed input */
 
-  char *y,*u,*oz;
-  int nz,mz;
-  int i;
-  
+  char *y = NULL,*u = NULL,*oz = NULL;
+  int nz = 0,mz = 0;
+    
   u=Getint8InPortPtrs(block,1);
   y=Getint8OutPortPtrs(block,1);
   oz=Getint8OzPtrs(block,1);
@@ -40,6 +41,7 @@ void delay4_i8(scicos_block *block,int flag)
   if ((flag==1)||(flag==6)||(flag==4)){
     y[0]=oz[0];
   }else if (flag == 2){
+	int i = 0;
     /*  shift buffer */
     for (i=0; i<=(mz*nz)-2; i++){
       oz[i]=oz[i+1];
@@ -48,3 +50,4 @@ void delay4_i8(scicos_block *block,int flag)
     oz[(mz*nz)-1]=u[0];
   }
 }
+/*--------------------------------------------------------------------------*/ 
