@@ -18,16 +18,18 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block.h"
-
-void dollar4(scicos_block *block,int flag)
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void dollar4(scicos_block *block,int flag)
 {
   /* c     Copyright INRIA
      
   Scicos block simulator
   Ouputs delayed input */
   
-  int i;
+  int i = 0;
   for(i=0;i< block->insz[0];i++){
     if (flag ==1 || flag ==6 || flag ==4)
       block->outptr[0][i]=block->z[i];
@@ -35,3 +37,4 @@ void dollar4(scicos_block *block,int flag)
       block->z[i]=block->inptr[0][i];
   }
 }
+/*--------------------------------------------------------------------------*/ 
