@@ -18,24 +18,19 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-#ifndef min
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-#endif
-
-#ifndef max
-#define max(a,b) ((a) >= (b) ? (a) : (b))
-#endif
-
-void extdiagz(scicos_block *block,int flag)
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void extdiagz(scicos_block *block,int flag)
 {
-  double *ur;
-  double *ui;
-  double *yr;
-  double *yi;
+  double *ur = NULL;
+  double *ui = NULL;
+  double *yr = NULL;
+  double *yi = NULL;
 
-  int mu,nu,i,ii;
+  int mu = 0,nu = 0,i = 0,ii = 0;
 
   mu=GetInPortRows(block,1);
   nu=GetInPortCols(block,1);
@@ -51,3 +46,4 @@ void extdiagz(scicos_block *block,int flag)
  	 *(yr+ii)=*(ur+ii);
 	 *(yi+ii)=*(ui+ii);}
 }
+/*--------------------------------------------------------------------------*/ 
