@@ -18,14 +18,17 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-void extract(scicos_block *block,int flag)
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void extract(scicos_block *block,int flag)
 {
-  double *u;
-  double *y;
-  int *r;
-  int nu,mu,nr,i,j,ij,k,nc,nl;
+  double *u = NULL;
+  double *y = NULL;
+  int *r = NULL;
+  int nu = 0,mu = 0,nr = 0,i = 0,j = 0,ij = 0,k = 0,nc = 0,nl = 0;
 
   mu=GetInPortRows(block,1);
   nu=GetInPortCols(block,1);
@@ -42,3 +45,4 @@ void extract(scicos_block *block,int flag)
 		 *(y+k)=*(u+ij);
 		 k++;}}
 }
+/*--------------------------------------------------------------------------*/ 
