@@ -18,13 +18,16 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block4.h"
+/*--------------------------------------------------------------------------*/ 
 #include <math.h>
-
-void extract_bit_16_UH1(scicos_block *block,int flag)
+#include "scicos_block4.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void extract_bit_16_UH1(scicos_block *block,int flag)
 {
-   int i,maxim;
-   short *y,*u,ref,n;
+   int i = 0,maxim = 0;
+   short *y = NULL,*u = NULL,ref = 0,n = 0;
    y=Getint16OutPortPtrs(block,1);
    u=Getint16InPortPtrs(block,1);
    maxim=16;
@@ -35,3 +38,4 @@ void extract_bit_16_UH1(scicos_block *block,int flag)
    *y=(*u)&(ref);
    *y=*y>>maxim/2;
 }
+/*--------------------------------------------------------------------------*/ 
