@@ -18,14 +18,17 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block4.h"
+/*--------------------------------------------------------------------------*/ 
 #include <math.h>
-
-void extract_bit_32_RB1(scicos_block *block,int flag)
+#include "scicos_block4.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void extract_bit_32_RB1(scicos_block *block,int flag)
 {
-   int i,maxim,numb;
-   long *y,*u,ref,n;
-   int *ipar;
+   int i = 0,maxim = 0,numb = 0;
+   long *y = NULL,*u = NULL,ref = 0,n = 0;
+   int *ipar = NULL;
    y=Getint32OutPortPtrs(block,1);
    u=Getint32InPortPtrs(block,1);
    ipar=GetIparPtrs(block);
@@ -38,3 +41,4 @@ void extract_bit_32_RB1(scicos_block *block,int flag)
    *y=(*u)&(ref);
    *y=*y>>*ipar;
 }
+/*--------------------------------------------------------------------------*/ 
