@@ -18,13 +18,17 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block4.h"
+/*--------------------------------------------------------------------------*/ 
 #include <math.h>
-
-void extract_bit_8_UH1(scicos_block *block,int flag)
+#include "scicos_block4.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void extract_bit_8_UH1(scicos_block *block,int flag)
 {
-   int i,maxim;
-   char *y,*u,ref,n;
+   int i = 0, maxim = 0;
+   char *y = 0,*u = 0,ref = 0,n = 0;
+
    y=Getint8OutPortPtrs(block,1);
    u=Getint8InPortPtrs(block,1);
    maxim=8;
@@ -35,3 +39,4 @@ void extract_bit_8_UH1(scicos_block *block,int flag)
    *y=(*u)&(ref);
    *y=*y>>maxim/2;
 }
+/*--------------------------------------------------------------------------*/ 
