@@ -18,13 +18,17 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block4.h"
+/*--------------------------------------------------------------------------*/ 
 #include <math.h>
-
-void extract_bit_u32_UH1(scicos_block *block,int flag)
+#include "scicos_block4.h"
+#include "MALLOC.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void extract_bit_u32_UH1(scicos_block *block,int flag)
 {
-   int i,maxim;
-   unsigned long *y,*u,ref,n;
+   int i = 0,maxim = 0;
+   unsigned long *y = NULL,*u = NULL,ref = 0,n = 0;
+
    y=Getuint32OutPortPtrs(block,1);
    u=Getuint32InPortPtrs(block,1);
    maxim=32;
@@ -35,3 +39,4 @@ void extract_bit_u32_UH1(scicos_block *block,int flag)
    *y=(*u)&(ref);
    *y=*y>>maxim/2;
 }
+/*--------------------------------------------------------------------------*/ 
