@@ -18,11 +18,12 @@
 *
 * See the file ./license.txt
 */
-# include "scicos_block4.h"
-# include "machine.h"
-# include <math.h>
-
-void matmul_i8n(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+#include <math.h>
+#include "scicos_block4.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void matmul_i8n(scicos_block *block,int flag)
 {
  if ((flag==1)|(flag==6)) {
   char *u1,*u2,*y; 
@@ -41,9 +42,10 @@ void matmul_i8n(scicos_block *block,int flag)
         for (l=0;l<nu2;l++)
 	    {for(j=0;j<mu1;j++)
 	        {D=0;
+		     jl=j+l*mu1;
 	        for(i=0;i<nu1;i++)
 		   {ji=j+i*mu1;
-		    jl=j+l*mu1;
+		   
 		    il=i+l*nu1;
 		    C=(double)(u1[ji])*(double)(u2[il]);
 		    D=D + C;}
@@ -52,3 +54,4 @@ void matmul_i8n(scicos_block *block,int flag)
 	     }
      }
 }
+/*--------------------------------------------------------------------------*/ 
