@@ -18,12 +18,15 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
+#include "machine.h"
 #include "scicos_block4.h"
-
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
 extern int C2F(dmmul)();
 extern int C2F(dmmul1)();
-
-void matmul_m(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void matmul_m(scicos_block *block,int flag)
 {
   double *u1;
   double *u2;
@@ -41,3 +44,4 @@ void matmul_m(scicos_block *block,int flag)
 
   C2F(dmmul)(u1,&nu,u2,&nu2,y,&nu,&nu,&nu2,&mu2);
 }
+/*--------------------------------------------------------------------------*/ 
