@@ -18,21 +18,21 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
+#include "machine.h"
 #include "scicos_block4.h"
-
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
 extern int C2F(mtran)();
-
-void mattran_m(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void mattran_m(scicos_block *block,int flag)
 {
-  double *u;
-  double *y;
-  int nu,mu;
+  int nu = GetInPortRows(block,1);
+  int mu = GetInPortCols(block,1);
 
-  nu=GetInPortRows(block,1);
-  mu=GetInPortCols(block,1);
-
-  u=GetRealInPortPtrs(block,1);
-  y=GetRealOutPortPtrs(block,1);
+  double *u = GetRealInPortPtrs(block,1);
+  double *y = GetRealOutPortPtrs(block,1);
 
   C2F(mtran)(u,&nu,y,&mu,&nu,&mu);
 }
+/*--------------------------------------------------------------------------*/ 
