@@ -18,24 +18,26 @@
 *
 * See the file ./license.txt
 */
-#include "scicos_block4.h"
+/*--------------------------------------------------------------------------*/ 
 #include <math.h>
-void matz_absc(scicos_block *block,int flag)
+#include "scicos_block4.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void matz_absc(scicos_block *block,int flag)
 {
-  double *u1;
-  double *u2;
-  double *y1r,*y1i;
 
-  int nu,mu,i;
+	int i = 0;
+	int mu=GetOutPortRows(block,1);
+	int nu=GetOutPortCols(block,1);
 
-  mu=GetOutPortRows(block,1);
-  nu=GetOutPortCols(block,1);
-  u1=GetRealInPortPtrs(block,1);
-  u2=GetRealInPortPtrs(block,2);
-  y1r=GetRealOutPortPtrs(block,1);
-  y1i=GetImagOutPortPtrs(block,1);
-  for (i=0;i<mu*nu;i++) 
-	{*(y1r+i)=(*(u1+i))*(cos(*(u2+i)));
-	 *(y1i+i)=(*(u1+i))*(sin(*(u2+i)));}
+	double *u1=GetRealInPortPtrs(block,1);
+	double *u2=GetRealInPortPtrs(block,2);
+	double *y1r=GetRealOutPortPtrs(block,1);
+	double *y1i=GetImagOutPortPtrs(block,1);
+	for (i=0;i<mu*nu;i++) 
+	{
+		*(y1r+i)=(*(u1+i))*(cos(*(u2+i)));
+		*(y1i+i)=(*(u1+i))*(sin(*(u2+i)));
+	}
 }
-
+/*--------------------------------------------------------------------------*/ 
