@@ -18,29 +18,34 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
 #include "scicos_block4.h"
-
-void matz_sumc(scicos_block *block,int flag)
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void matz_sumc(scicos_block *block,int flag)
 {
-  double *ur;
-  double *ui;
-  double *yr;
-  double *yi;
-  int nu,mu,i,j,ij;
-  double dr,di;
-  mu=GetInPortRows(block,1);
-  nu=GetInPortCols(block,1);
-  ur=GetRealInPortPtrs(block,1);
-  ui=GetImagInPortPtrs(block,1);
-  yr=GetRealOutPortPtrs(block,1);
-  yi=GetImagOutPortPtrs(block,1);
-  for(j=0;j<nu;j++)
-       {dr=0;
-	di=0;
-	for (i=0;i<mu;i++)
-	   {ij=i+j*mu;
-	    dr+=*(ur+ij);
-	    di+=*(ui+ij);}
-	*(yr+j)=dr;
-	*(yi+j)=di;}
+	int j = 0;
+	int mu = GetInPortRows(block,1);
+	int nu = GetInPortCols(block,1);
+
+	double *ur = GetRealInPortPtrs(block,1);
+	double *ui = GetImagInPortPtrs(block,1);
+	double *yr = GetRealOutPortPtrs(block,1);
+	double *yi = GetImagOutPortPtrs(block,1);
+
+	for(j=0;j<nu;j++)
+	{
+		double dr = 0.;
+		double di = 0.;
+		int i = 0;
+		for (i=0;i<mu;i++)
+		{
+			int ij = i+j*mu;
+			dr += *(ur+ij);
+			di += *(ui+ij);
+		}
+		*(yr+j)=dr;
+		*(yi+j)=di;
+	}
 }
+/*--------------------------------------------------------------------------*/ 
