@@ -18,19 +18,22 @@
 *
 * See the file ./license.txt
 */
+/*--------------------------------------------------------------------------*/ 
+#include "machine.h"
 #include "scicos_block4.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
 extern int C2F(wprxc)();
-void rootz_coef(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void rootz_coef(scicos_block *block,int flag)
 {
-  double *ur,*ui;
-  double *yr,*yi;
-  int mu;
-  mu=GetInPortRows(block,1);
+	int mu = GetInPortRows(block,1);
 
-  ur=GetRealInPortPtrs(block,1);
-  ui=GetImagInPortPtrs(block,1);
-  yr=GetRealOutPortPtrs(block,1);
-  yi=GetImagOutPortPtrs(block,1);
-  if (flag==1||flag==6)
-  C2F(wprxc)(&mu,ur,ui,yr,yi);
+	double *ur = GetRealInPortPtrs(block,1);
+	double *ui = GetImagInPortPtrs(block,1);
+	double *yr = GetRealOutPortPtrs(block,1);
+	double *yi = GetImagOutPortPtrs(block,1);
+
+	if (flag==1||flag==6) C2F(wprxc)(&mu,ur,ui,yr,yi);
 }
+/*--------------------------------------------------------------------------*/ 
