@@ -18,19 +18,20 @@
 *
 * See the file ./license.txt
 */
-# include "scicos_block4.h"
-# include "machine.h"
-# include <math.h>
-
-void shift_u32_RA(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+#include <math.h>
+#include "scicos_block4.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void shift_u32_RA(scicos_block *block,int flag)
 {
-  unsigned long *u,*y; 
-  int *ipar;
-  int mu,nu,i;
-  mu=GetInPortRows(block,1);
-  nu=GetInPortCols(block,1);
-  u=Getuint32InPortPtrs(block,1);
-  y=Getuint32OutPortPtrs(block,1);
-  ipar=GetIparPtrs(block);
-  for (i=0;i<mu*nu;i++) y[i]=u[i]>>-ipar[0];
+	int i = 0;
+	int mu = GetInPortRows(block,1);
+	int nu = GetInPortCols(block,1);
+	unsigned long *u = Getuint32InPortPtrs(block,1);
+	unsigned long *y = Getuint32OutPortPtrs(block,1);
+	int *ipar = GetIparPtrs(block);
+
+	for (i=0;i<mu*nu;i++) y[i]=u[i]>>-ipar[0];
 }
+/*--------------------------------------------------------------------------*/ 
