@@ -18,19 +18,20 @@
 *
 * See the file ./license.txt
 */
-# include "scicos_block4.h"
-# include "machine.h"
-# include <math.h>
-
-void shift_u8_RA(scicos_block *block,int flag)
+/*--------------------------------------------------------------------------*/ 
+#include <math.h>
+#include "scicos_block4.h"
+#include "dynlib_scicos_blocks.h"
+/*--------------------------------------------------------------------------*/ 
+SCICOS_BLOCKS_IMPEXP void shift_u8_RA(scicos_block *block,int flag)
 {
-  unsigned char *u,*y; 
-  int *ipar;
-  int mu,nu,i;
-  mu=GetInPortRows(block,1);
-  nu=GetInPortCols(block,1);
-  u=Getuint8InPortPtrs(block,1);
-  y=Getuint8OutPortPtrs(block,1);
-  ipar=GetIparPtrs(block);
-  for (i=0;i<mu*nu;i++) y[i]=u[i]>>(-ipar[0]);
+	int i = 0;
+	int mu = GetInPortRows(block,1);
+	int nu = GetInPortCols(block,1);
+	unsigned char *u = Getuint8InPortPtrs(block,1);
+	unsigned char *y = Getuint8OutPortPtrs(block,1);
+	int *ipar = GetIparPtrs(block);
+
+	for (i=0;i<mu*nu;i++) y[i]=u[i]>>(-ipar[0]);
 }
+/*--------------------------------------------------------------------------*/ 
