@@ -19,34 +19,37 @@ import java.awt.Graphics;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.Shape;
-import java.awt.event.MouseListener;
-import java.awt.event.MouseMotionListener;
-import java.awt.event.MouseEvent;
 import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.KeyListener;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
+import java.awt.event.MouseMotionListener;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.EventObject;
 import java.util.List;
 import java.util.UUID;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
-import javax.swing.text.Caret;
-import javax.swing.JComponent;
 import javax.swing.JEditorPane;
 import javax.swing.JScrollBar;
 import javax.swing.JScrollPane;
 import javax.swing.JSplitPane;
 import javax.swing.SwingUtilities;
+import javax.swing.UIManager;
+import javax.swing.event.CaretEvent;
+import javax.swing.event.CaretListener;
 import javax.swing.text.BadLocationException;
+import javax.swing.text.Caret;
+import javax.swing.text.DefaultHighlighter;
 import javax.swing.text.Document;
 import javax.swing.text.Element;
 import javax.swing.text.Highlighter;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.View;
-import javax.swing.event.CaretEvent;
-import javax.swing.event.CaretListener;
 
 import org.scilab.modules.commons.gui.ScilabCaret;
 import org.scilab.modules.console.utils.ScilabLaTeXViewer;
@@ -62,13 +65,16 @@ import org.scilab.modules.scinotes.utils.SciNotesMessages;
  *
  */
 public class ScilabEditorPane extends JEditorPane implements Highlighter.HighlightPainter,
-                                                             CaretListener, MouseListener,
-                                                             MouseMotionListener, Cloneable,
-                                                             KeyListener {
+                                                  CaretListener, MouseListener,
+                                                  MouseMotionListener, Cloneable,
+                                                  KeyListener {
+
+    private static final long serialVersionUID = 4322071415211939097L;
 
     private static final String TIRET = " - ";
     private static final Cursor HANDCURSOR = Cursor.getPredefinedCursor(Cursor.HAND_CURSOR);
     private static final Cursor TEXTCURSOR = Cursor.getPredefinedCursor(Cursor.TEXT_CURSOR);
+    private static final DefaultHighlighter.DefaultHighlightPainter HIGHLIGHTER = new DefaultHighlighter.DefaultHighlightPainter(Color.YELLOW);
 
     private static ScilabEditorPane focused;
 
@@ -102,7 +108,6 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
     private boolean suppressCom = true;
 
     private SciNotesLineNumberPanel xln;
-    private JSplitPane split;
     private ScilabEditorPane rightTextPane;
     private UUID uuid;
 
@@ -117,7 +122,9 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
     private boolean hasBeenSaved;
     private boolean saveHighlightEnable;
 
-    private List<KeywordListener> kwListeners = new ArrayList();
+    private List<KeywordListener> kwListeners = new ArrayList<KeywordListener>();
+    private List<Object> highlightedWords = new ArrayList<Object>();
+    private List<Integer> highlightedWordsBegin = new ArrayList<Integer>();
 
     /**
      * Constructor
@@ -130,7 +137,6 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
         }
         this.editor = editor;
         this.uuid = UUID.randomUUID();
-        updateCaret();
         edComponent = new EditorComponent(this);
 
         addCaretListener(this);
@@ -631,15 +637,39 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
      * @param pos the position in the document
      */
     public void scrollTextToPos(int pos) {
-        try {
-            setCaretPosition(pos);
-            JScrollBar scrollbar = edComponent.getScrollPane().getVerticalScrollBar();
-            int value = modelToView(pos).y;
-            if (modelToView(pos).y > scrollbar.getMaximum()) {
-                scrollbar.setMaximum(value);
-            }
-            scrollbar.setValue(value);
-        } catch (BadLocationException e) { }
+        scrollTextToPos(pos, true, false);
+    }
+
+    /**
+     * Scroll the pane to have the line containing pos on the top or centered on the pane
+     * @param pos the position in the document
+     * @param setCaret, if true the caret is set at the given position
+     * @param centered, if true the line is centered
+     */
+    public void scrollTextToPos(final int pos, final boolean setCaret, final boolean centered) {
+        SwingUtilities.invokeLater(new Runnable() {
+                public void run() {
+                    try {
+                        if (setCaret) {
+                            setCaretPosition(pos);
+                        }
+                        JScrollBar scrollbar = edComponent.getScrollPane().getVerticalScrollBar();
+                        Rectangle rect = modelToView(pos);
+                        if (centered) {
+                            int value = scrollbar.getValue();
+                            int h = scrollbar.getHeight();
+                            if (rect.y < value || rect.y > value + h) {
+                                scrollbar.setValue(Math.max(0, rect.y - h / 2));
+                            }
+                        } else {
+                            if (rect.y > scrollbar.getMaximum()) {
+                                scrollbar.setMaximum(rect.y);
+                            }
+                            scrollbar.setValue(rect.y);
+                        }
+                    } catch (BadLocationException e) { }
+                }
+            });
     }
 
     /**
@@ -647,13 +677,24 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
      * @param lineNumber the number of the line
      * @param highlight true to highlight the line
      */
-    public void scrollTextToLineNumber(int lineNumber, final boolean highlight) {
+    public void scrollTextToLineNumber(int lineNumber, boolean highlight) {
+        scrollTextToLineNumber(lineNumber, highlight, true, false);
+    }
+
+    /**
+     * Scroll the pane to have the line lineNumber on the top or centered on the pane
+     * @param lineNumber the number of the line
+     * @param highlight true to highlight the line
+     * @param setCaret, if true the caret is set at the given line
+     * @param centered, if true the line is centered
+     */
+    public void scrollTextToLineNumber(int lineNumber, final boolean highlight, final boolean setCaret, final boolean centered) {
         Element root = getDocument().getDefaultRootElement();
         if (lineNumber >= 1 && lineNumber <= root.getElementCount()) {
             final int pos = root.getElement(lineNumber - 1).getStartOffset();
             SwingUtilities.invokeLater(new Runnable() {
                     public void run() {
-                        scrollTextToPos(pos);
+                        scrollTextToPos(pos, setCaret, centered);
                         if (highlight) {
                             saveHighlightContourColor = highlightContourColor;
                             highlightContourColor = null;
@@ -669,6 +710,42 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
         }
     }
 
+    /**
+     * Scroll the pane to have the line lineNumber on the top of the pane in whereami mode
+     * The line number is computed regarding the function named funname.
+     * @param lineNumber the number of the line
+     * @param funname the function name
+     * @param highlight true to highlight the line
+     */
+    public void scrollTextToLineNumberInWhereami(int lineNumber, String funname, boolean highlight) {
+        scrollTextToLineNumberInWhereami(lineNumber, funname, highlight, true, false);
+    }
+
+    /**
+     * Scroll the pane to have the line lineNumber on the top of the pane in whereami mode
+     * The line number is computed regarding the function named funname.
+     * @param lineNumber the number of the line
+     * @param funname the function name
+     * @param highlight true to highlight the line
+     * @param setCaret, if true the caret is set at the given line
+     * @param centered, if true the line is centered
+     */
+    public void scrollTextToLineNumberInWhereami(int lineNumber, String funname, boolean highlight, boolean setCaret, boolean centered) {
+        if (funname != null) {
+            Element root = getDocument().getDefaultRootElement();
+            int nlines = root.getElementCount();
+            ScilabDocument.ScilabLeafElement elem;
+            for (int i = 0; i < nlines; i++) {
+                elem = (ScilabDocument.ScilabLeafElement) root.getElement(i);
+                if (elem.getFunctionName().equals(funname)) {
+                    lineNumber += i;
+                    break;
+                }
+            }
+        }
+        scrollTextToLineNumber(lineNumber, highlight, setCaret, centered);
+    }
+
     /**
      * @return the width of a white
      */
@@ -746,12 +823,15 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
      */
     public String getCodeToExecute() {
         String selection;
+        int start, end;
+        start = getSelectionStart();
+        end = getSelectionEnd();
+
         if (((SciNotesCaret) getCaret()).isEmptySelection()) {
-            int start = getSelectionStart();
-            int end = getSelectionEnd();
             try {
                 if (start == end) {
                     selection = getDocument().getText(0, start);
+                    start = 0;
                 } else {
                     selection = getSelectedText();
                 }
@@ -763,7 +843,21 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
         }
 
         if (suppressCom) {
-            selection = selection.replaceAll("[ \t]*//[^\n]*", "");
+            StringBuffer buf = new StringBuffer(selection.length());
+            int sstart = start;
+            int tok = lexer.getKeyword(start, false);
+            int len = selection.length();
+            while (start < end) {
+                int pos = lexer.start + lexer.yychar() + lexer.yylength();
+                String str = selection.substring(start - sstart, Math.min(pos - sstart, len));
+                if (tok != ScilabLexerConstants.COMMENT || str.equals("\n")) {
+                    buf.append(str);
+                }
+                start = pos;
+                tok = lexer.getKeyword(start, false);
+            }
+
+            return buf.toString();
         }
 
         return selection;
@@ -877,6 +971,16 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
             removeHighlightForLine();
         }
 
+        if (hasFocus()) {
+            String str = getSelectedText();
+            if (str != null && str.length() != 0) {
+                highlightWords(str, true);
+                removeHighlightOnPosition(getSelectionStart());
+            } else {
+                removeHighlightedWords();
+            }
+        }
+
         if (highlightEnable) {
             repaint();
         }
@@ -1059,6 +1163,9 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
         if (hasBeenSaved) {
             removeHighlightForLine();
         }
+
+        removeHighlightedWords();
+
         if (highlightEnable) {
             repaint();
         }
@@ -1087,6 +1194,9 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
         if (hasBeenSaved) {
             removeHighlightForLine();
         }
+
+        removeHighlightedWords();
+
         if (highlightEnable) {
             repaint();
         }
@@ -1186,6 +1296,39 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
         return null;
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    public void setCaret(Caret c) {
+        if (!(c instanceof ScilabCaret)) {
+            final Caret caret = new SciNotesCaret(this);
+            setCaretColor(getCaretColor());
+            SwingUtilities.invokeLater(new Runnable() {
+                    public void run() {
+                        int blinkRate = 500;
+                        Object o = UIManager.get("TextComponent.caretBlinkRate");
+                        if ((o != null) && (o instanceof Integer)) {
+                            Integer rate = (Integer) o;
+                            blinkRate = rate.intValue();
+                        }
+                        caret.setBlinkRate(blinkRate);
+                        caret.setVisible(true);
+                    }
+                });
+            super.setCaret(caret);
+        } else {
+            super.setCaret(c);
+        }
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public void select(int start, int end) {
+        removeHighlightOnPosition(start);
+        super.select(start, end);
+    }
+
     /**
      * Remove the highlight putted to show the line (for editor('foo',123))
      */
@@ -1200,13 +1343,83 @@ public class ScilabEditorPane extends JEditorPane implements Highlighter.Highlig
     }
 
     /**
-     * Add a the ScilabCaret
+     * Remove the highlight at position start
+     * @param start the beginning of the highlight
      */
-    private void updateCaret() {
-        Caret caret = new SciNotesCaret(this);
-        caret.setBlinkRate(getCaret().getBlinkRate());
-        setCaretColor(getCaretColor());
-        setCaret(caret);
+    public void removeHighlightOnPosition(int start) {
+        int pos = highlightedWordsBegin.indexOf(start);
+        if (pos != -1) {
+            getHighlighter().removeHighlight(highlightedWords.remove(pos));
+            highlightedWordsBegin.remove(pos);
+        }
+    }
+
+    /**
+     * Highlight a word in this textpane.
+     * @param word the word to highlight
+     * @param exact if true the search is case sensitive
+     */
+    public void highlightWords(String word, boolean exact) {
+        removeHighlightedWords();
+        if (word != null && word.length() != 0) {
+            String text = getText();
+            if (!exact) {
+                text = text.toLowerCase();
+                word = word.toLowerCase();
+            }
+
+            int pos = text.indexOf(word, 0);
+            int len = word.length();
+            Highlighter highlighter = getHighlighter();
+            while (pos != -1) {
+                try {
+                    highlightedWords.add(highlighter.addHighlight(pos, pos + len, HIGHLIGHTER));
+                    highlightedWordsBegin.add(pos);
+                } catch (BadLocationException e) { }
+                pos = text.indexOf(word, pos + len);
+            }
+        }
+    }
+
+    /**
+     * Highlight a word according to a pattern in this textpane.
+     * @param pattern the pattern to highlight
+     * @param centered, if true the pane is centered on the first occurence
+     */
+    public void highlightWords(Pattern pattern, boolean centered) {
+        if (pattern != null) {
+            removeHighlightedWords();
+            int first = -1;
+            String text = getText();
+            Matcher matcher = pattern.matcher(text);
+
+            Highlighter highlighter = getHighlighter();
+            while (matcher.find()) {
+                if (first == -1) {
+                    first = matcher.start();
+                }
+                try {
+                    highlightedWords.add(highlighter.addHighlight(matcher.start(), matcher.end(), HIGHLIGHTER));
+                    highlightedWordsBegin.add(matcher.start());
+                } catch (BadLocationException e) { }
+            }
+
+            if (centered && first != -1) {
+                scrollTextToPos(first, false, true);
+            }
+        }
+    }
+
+    /**
+     * Remove all the highlighted words
+     */
+    public void removeHighlightedWords() {
+        Highlighter highlighter = getHighlighter();
+        for (Object obj : highlightedWords) {
+            highlighter.removeHighlight(obj);
+        }
+        highlightedWords.clear();
+        highlightedWordsBegin.clear();
     }
 
     /**
