@@ -46,7 +46,6 @@ public class ScilabPlainView extends PlainView {
 
     private ScilabContext context;
     private ScilabLexer lexer;
-    private boolean lexerValid;
     private ScilabDocument doc;
     private Segment text = new Segment();
     private boolean isTabViewable = true;
@@ -84,7 +83,6 @@ public class ScilabPlainView extends PlainView {
         }
         doc.setView(this);
         lexer = doc.createLexer();
-        lexerValid = false;
         setTabRepresentation(ScilabView.TABVERTICAL);
     }
 
@@ -218,7 +216,6 @@ public class ScilabPlainView extends PlainView {
         int tok = -1;
         int mark = p0;
         int start = p0;
-        int sstart = -1;
         int x = sx;
         int y = sy;
         boolean isBroken = false;
@@ -242,7 +239,8 @@ public class ScilabPlainView extends PlainView {
             lexer.setRange(start, endL);
         }
 
-        while (start < p1 && sstart != start) {
+        while (start < p1 && tok != ScilabLexerConstants.EOF) {
+
             try {
                 if (!isBroken) {
                     tok = lexer.scan();
@@ -251,7 +249,6 @@ public class ScilabPlainView extends PlainView {
                 }
             } catch (IOException e) { }
 
-            sstart = start;
             start = lexer.start + lexer.yychar();
 
             int end = Math.min(p1, start + lexer.yylength());
@@ -297,6 +294,20 @@ public class ScilabPlainView extends PlainView {
                         paintTab(text, x, y, g, mark);
                     }
                     break;
+                case ScilabLexerConstants.ERROR :
+                    if (unselected) {
+                        g.setColor(Color.RED);
+                    } else {
+                        g.setColor(Color.WHITE);
+                    }
+                    w = Utilities.getTabbedTextWidth(text, g.getFontMetrics(), x, this, mark);
+                    for (int i = 0; i < w; i +=4) {
+                        g.drawLine(x + i, y + 2, x + i + 1, y + 2);
+                    }
+                    for (int i = 2; i < w; i +=4) {
+                        g.drawLine(x + i, y + 1, x + i + 1, y + 1);
+                    }
+                    break;
                 default :
                     break;
                 }
