@@ -14,7 +14,6 @@ package org.scilab.modules.scinotes.actions;
 
 import java.awt.BorderLayout;
 import java.awt.Color;
-import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
 import java.awt.KeyboardFocusManager;
@@ -22,9 +21,10 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
+import java.awt.event.ItemEvent;
+import java.awt.event.ItemListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.KeyListener;
-
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
@@ -32,19 +32,19 @@ import java.util.Map;
 import javax.swing.AbstractAction;
 import javax.swing.ImageIcon;
 import javax.swing.JButton;
+import javax.swing.JCheckBox;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
 import javax.swing.KeyStroke;
-import javax.swing.SwingUtilities;
 
 import org.scilab.modules.commons.ScilabConstants;
 import org.scilab.modules.gui.menuitem.MenuItem;
 import org.scilab.modules.gui.pushbutton.PushButton;
 import org.scilab.modules.gui.textbox.TextBox;
-import org.scilab.modules.gui.bridge.window.SwingScilabWindow;
 import org.scilab.modules.scinotes.SciNotes;
 import org.scilab.modules.scinotes.ScilabDocument;
 import org.scilab.modules.scinotes.ScilabEditorPane;
+import org.scilab.modules.scinotes.utils.SciNotesMessages;
 
 /**
  * IncrementalSearchAction Class
@@ -52,6 +52,7 @@ import org.scilab.modules.scinotes.ScilabEditorPane;
  */
 public final class IncrementalSearchAction extends DefaultAction {
 
+    private static final long serialVersionUID = -3093932085002970876L;
     private static final String SCI = ScilabConstants.SCI.getPath();
     private static final String TAB = "tab";
     private static final ImageIcon CLOSEICON = new ImageIcon(SCI + "/modules/gui/images/icons/close-tab.png");
@@ -59,10 +60,7 @@ public final class IncrementalSearchAction extends DefaultAction {
     private static final ImageIcon BOTICON = new ImageIcon(SCI + "/modules/gui/images/icons/16x16/actions/go-bottom.png");
     private static final int BUTTONSIZE = 28;
 
-    private static Map<SciNotes, SearchField> fields = new HashMap();
-
-    private TextBox info;
-    private JPanel panelInfoSearch;
+    private static Map<SciNotes, SearchField> fields = new HashMap<SciNotes, SearchField>();
 
     /**
      * Constructor
@@ -80,7 +78,7 @@ public final class IncrementalSearchAction extends DefaultAction {
         if (!fields.containsKey(getEditor())) {
             SearchField field = new SearchField();
             fields.put(getEditor(), field);
-            getEditor().getTextPane().getEditorComponent().insertBottomComponent(field);
+            getEditor().insertBottomComponent(field);
             field.requestFocus();
         } else {
             fields.get(getEditor()).requestFocus();
@@ -119,6 +117,30 @@ public final class IncrementalSearchAction extends DefaultAction {
         }
     }
 
+    /**
+     * @param editor the editor where to close the search bar
+     * @return the word which is currently searching
+     */
+    public static String getWord(SciNotes editor) {
+        if (fields.containsKey(editor)) {
+            return fields.get(editor).getWord();
+        }
+
+        return null;
+    }
+
+    /**
+     * @param editor the editor where to close the search bar
+     * @return true if it is an exact search
+     */
+    public static boolean getExact(SciNotes editor) {
+        if (fields.containsKey(editor)) {
+            return fields.get(editor).getExact();
+        }
+
+        return false;
+    }
+
     /**
      * Inner class to have an incremental search field.
      */
@@ -126,7 +148,7 @@ public final class IncrementalSearchAction extends DefaultAction {
 
         private String text;
         private JTextField field;
-        private TopBotButtons[] buttons = new TopBotButtons[2];
+        private boolean exact;
 
         /**
          * Default Constructor
@@ -147,11 +169,33 @@ public final class IncrementalSearchAction extends DefaultAction {
             panelButtons.add(new CloseButton());
             panelButtons.add(new TopBotButtons(true));
             panelButtons.add(new TopBotButtons(false));
+            JCheckBox check = new JCheckBox(SciNotesMessages.EXACT);
+            check.addItemListener(new ItemListener() {
+                    public void itemStateChanged(ItemEvent e) {
+                        exact = e.getStateChange() == ItemEvent.SELECTED;
+                        changeText();
+                    }
+                });
+            panelButtons.add(check);
             add(panelButtons, BorderLayout.WEST);
             add(field, BorderLayout.CENTER);
             setVisible(true);
         }
 
+        /**
+         * @return the word which is currently searching
+         */
+        public String getWord() {
+            return field.getText();
+        }
+
+        /**
+         * @return true if it is an exact search
+         */
+        public boolean getExact() {
+            return exact;
+        }
+
         /**
          * {@inheritDoc}
          */
@@ -163,9 +207,8 @@ public final class IncrementalSearchAction extends DefaultAction {
          * {@inheritDoc}
          */
         public void focusGained(FocusEvent e) {
-            if (text == null && getEditor().getTextPane() != null) {
-                ScilabDocument doc = (ScilabDocument) getEditor().getTextPane().getDocument();
-                text = doc.getText().toLowerCase();
+            if (text == null) {
+                changeText();
             }
             field.select(0, field.getText().length());
         }
@@ -191,7 +234,7 @@ public final class IncrementalSearchAction extends DefaultAction {
         public void hideField() {
             removeListeners();
             fields.remove(getEditor());
-            getEditor().getTextPane().getEditorComponent().insertBottomComponent(null);
+            getEditor().insertBottomComponent(null);
         }
 
         /**
@@ -210,7 +253,10 @@ public final class IncrementalSearchAction extends DefaultAction {
                 int start;
                 String str = field.getText();
                 if (str != null) {
-                    str = str.toLowerCase();
+                    sep.highlightWords(str, exact);
+                    if (!exact) {
+                        str = str.toLowerCase();
+                    }
                     if (key == KeyEvent.VK_ENTER && ((e.getModifiers() & KeyEvent.SHIFT_MASK) != 0)) {
                         start = text.lastIndexOf(str, pos - 1);
                         e.consume();
@@ -240,6 +286,21 @@ public final class IncrementalSearchAction extends DefaultAction {
          */
         public void keyPressed(KeyEvent e) { }
 
+        /**
+         * Change the text where to search
+         */
+        private void changeText() {
+            if (getEditor().getTextPane() != null) {
+                ScilabEditorPane sep = getEditor().getTextPane();
+                ScilabDocument doc = (ScilabDocument) sep.getDocument();
+                text = doc.getText();
+                if (!exact) {
+                    text = text.toLowerCase();
+                }
+                sep.highlightWords(field.getText(), exact);
+            }
+        }
+
         /**
          * Inner class for the close-buttons
          */
@@ -289,10 +350,15 @@ public final class IncrementalSearchAction extends DefaultAction {
                             String str = field.getText();
 
                             ScilabDocument doc = (ScilabDocument) getEditor().getTextPane().getDocument();
-                            String txt = doc.getText().toLowerCase();
+                            String txt = doc.getText();
+                            if (!exact) {
+                                txt = txt.toLowerCase();
+                            }
 
                             if (str != null) {
-                                str = str.toLowerCase();
+                                if (!exact) {
+                                    str = str.toLowerCase();
+                                }
                                 if (top) {
                                     start = txt.lastIndexOf(str, pos - 1);
                                 } else {
