@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intinpnvi)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_inpnvi)(char *fname,unsigned long fname_len)
+int sci_inpnvi(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intinpnvi)(id);
