@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intludel)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_ludel)(char *fname,unsigned long fname_len)
+int sci_ludel(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intludel)(id);
