@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intluget)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_luget)(char *fname,unsigned long fname_len)
+int sci_luget(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intluget)(id);
