@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intlusolve)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_lusolve)(char *fname,unsigned long fname_len)
+int sci_lusolve(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intlusolve)(id);
