@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intmfull)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_mfull)(char *fname,unsigned long fname_len)
+int sci_mfull(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intmfull)(id);
