@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intmsparse)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_msparse)(char *fname,unsigned long fname_len)
+int sci_msparse(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intmsparse)(id);
