@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intmspget)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_mspget)(char *fname,unsigned long fname_len)
+int sci_mspget(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intmspget)(id);
