@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intnnz)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_nnz)(char *fname,unsigned long fname_len)
+int sci_nnz(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intnnz)(id);
