@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intordmmd)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_ordmmd)(char *fname,unsigned long fname_len)
+int sci_ordmmd(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intordmmd)(id);
