@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intsfinit)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_sfinit)(char *fname,unsigned long fname_len)
+int sci_sfinit(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intsfinit)(id);
