@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intspchol)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_spchol)(char *fname,unsigned long fname_len)
+int sci_spchol(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intspchol)(id);
