@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intspcompa)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_spcompa)(char *fname,unsigned long fname_len)
+int sci_spcompa(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intspcompa)(id);
