@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intspget)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_spget)(char *fname,unsigned long fname_len)
+int sci_spget(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intspget)(id);
