@@ -9,14 +9,13 @@
  * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
  *
  */
-
-#include "gw_special_functions1.h"
-#include "stack-c.h"
 #include <string.h>
+#include "gw_special_functions.h"
+#include "machine.h"
 /*--------------------------------------------------------------------------*/
 extern int C2F(intsdlgamma)(char *id,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_dlgamma)(char *fname,unsigned long fname_len)
+int sci_dlgamma(char *fname,unsigned long fname_len)
 {
 	C2F(intsdlgamma)(fname,fname_len);
 	return 0;
