@@ -16,16 +16,16 @@
 #include "stack-c.h"
 #include "callFunctionFromGateway.h"
 /*--------------------------------------------------------------------------*/ 
-static gw_generic_table Tab[]={
-	{C2F(sci_xls_open),"xls_open"},
-	{C2F(sci_xls_read),"xls_read"}
+static gw_generic_table Tab[] = 
+{
+	{sci_xls_open,"xls_open"},
+	{sci_xls_read,"xls_read"}
 };
 /*--------------------------------------------------------------------------*/ 
 int gw_spreadsheet(void)
 {  
 	Rhs = Max(0, Rhs);
-	callFunctionFromGateway(Tab);
-
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 	return 0;
 }
 /*--------------------------------------------------------------------------*/ 
