@@ -13,21 +13,22 @@
 #ifndef __GW_STATISTICS__
 #define __GW_STATISTICS__
 /*--------------------------------------------------------------------------*/ 
-#include "machine.h"
+#include "dynlib_statistics.h"
+#include "api_common.h"
 /*--------------------------------------------------------------------------*/ 
-int gw_statistics(void);
+STATISTICS_IMPEXP int gw_statistics(void);
 /*--------------------------------------------------------------------------*/ 
-int cdfbetI(char* fname,unsigned long l);
-int cdfbinI(char* fname,unsigned long l);
-int cdfchiI(char* fname,unsigned long l);
-int cdfchnI(char* fname,unsigned long l);
-int cdffI(char* fname,unsigned long l);
-int cdffncI(char* fname,unsigned long l);
-int cdfgamI(char* fname,unsigned long l);
-int cdfnbnI(char* fname,unsigned long l);
-int cdfnorI(char* fname,unsigned long l);
-int cdfpoiI(char* fname,unsigned long l);
-int cdftI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfbetI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfbinI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfchiI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfchnI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdffI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdffncI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfgamI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfnbnI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfnorI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdfpoiI(char* fname,unsigned long l);
+STATISTICS_IMPEXP int cdftI(char* fname,unsigned long l);
 /*--------------------------------------------------------------------------*/ 
 #endif /*  __GW_STATISTICS__ */
 /*--------------------------------------------------------------------------*/
