@@ -15,7 +15,7 @@
 #include "stack-c.h"
 #include "callFunctionFromGateway.h"
 /*--------------------------------------------------------------------------*/
-static gw_generic_table Tab[]=
+static gw_generic_table Tab[] =
 { 
 	{cdfbetI, "cdfbet"},
 	{cdfbinI, "cdfbin"},
@@ -33,7 +33,7 @@ static gw_generic_table Tab[]=
 int gw_statistics()
 {  
 	Rhs = Max(0, Rhs);
-	callFunctionFromGateway(Tab);
+	callFunctionFromGateway(Tab, SIZE_CURRENT_GENERIC_TABLE(Tab));
 	return 0;
 }
 /*--------------------------------------------------------------------------*/
