@@ -14,6 +14,10 @@
 #ifndef __CDFBASE_H__
 #define __CDFBASE_H__
 
+/* see cdff.f line 97 */
+#define INFINITY_FOR_CDF 1.0e300
+#define ZERO_FOR_CDF 1.0e-300
+
 /**
  * TODO : needs comments
  * @param fname
@@ -27,7 +31,14 @@
  * @param (*foncErr)()
  * @return
  */
-
 int  CdfBase(char *fname,int inarg,int oarg,int *callpos,char *option,char *errnames,int which,int (*fonc)(),void (*foncErr)() );
 
+
+/* messages error */
+void CdfDefaultError(char** param, int status, double bound);
+
+void cdfLowestSearchError(double bound);
+
+void cdfGreatestSearchError(double bound);
+
 #endif /* __CDFBASE_H__ */
