@@ -15,6 +15,7 @@
 #define __GW_STRING__
 #include "api_scilab.h"
 #include "dynlib_string.h"
+#include "BOOL.h"
 
 /*--------------------------------------------------------------------------*/ 
 STRING_IMPEXP int gw_string(void);
@@ -41,7 +42,6 @@ STRING_IMPEXP int sci_isalphanum(char *fname,unsigned long fname_len);
 STRING_IMPEXP int sci_isascii(char *fname,unsigned long fname_len);
 STRING_IMPEXP int sci_strcspn(char *fname,unsigned long fname_len);
 STRING_IMPEXP int sci_strncpy(char *fname,unsigned long fname_len);
-STRING_IMPEXP int sci_strrchr(char *fname,unsigned long fname_len);
 STRING_IMPEXP int sci_strchr(char *fname,unsigned long fname_len);
 STRING_IMPEXP int sci_strstr(char *fname,unsigned long fname_len);
 STRING_IMPEXP int sci_strrev(char *fname,unsigned long fname_len);
