@@ -15,6 +15,8 @@
 #ifndef __STRSUBST_H__
 #define __STRSUBST_H__
 
+#include "dynlib_string.h"
+
 /**
 * substitute a character string by another in a character string in string matrix
 * @param[in] strings_input
@@ -23,16 +25,18 @@
 * @param[in] replacement_string
 * @return substituted string matrix
 */
-char **strsubst(char **strings_input,int strings_dim,char *string_to_search,char *replacement_string);
-char **strsubst_reg(char **strings_input,int strings_dim,char *string_to_search,char *replacement_string);
+STRING_IMPEXP char **strsubst(char **strings_input,int strings_dim,char *string_to_search,char *replacement_string);
+STRING_IMPEXP char **strsubst_reg(char **strings_input,int strings_dim,char *string_to_search,char *replacement_string, int *ierr);
+
 /**
 * substitute a character string by another in a character string
 * @param[in] string 
 * @param[in] string to search in input_string
 * @param[in] replacement_string
+* @param[out] error returned by pcre_private
 * @return substituted string
 */
-char *strsub(char* input_string, const char* string_to_search, const char* replacement_string);
-char *strsub_reg(char* input_string, const char* string_to_search, const char* replacement_string);
+STRING_IMPEXP char *strsub(char* input_string, const char* string_to_search, const char* replacement_string);
+STRING_IMPEXP char *strsub_reg(char* input_string, const char* string_to_search, const char* replacement_string, int *ierr);
 
 #endif /* __STRSUBST_H__ */
