@@ -1,4 +1,3 @@
-
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) INRIA - Cong WU
@@ -121,7 +120,7 @@ static int asciiStrings(char *fname)
 	if (Output_IntMatrix == NULL)
 	{
 		freeArrayOfString(Input_StringMatrix,Row_Num*Col_Num);
-		Scierror(999,_("%s : Memory allocation error.\n"),fname);
+		Scierror(999,_("%s: Memory allocation error.\n"),fname);
 		return 0;
 	}
 
@@ -174,7 +173,7 @@ static int asciiStrings(char *fname)
 		if (Err > 0) 
 		{
 			/* stacksize exceeded */
-			Error(17);
+			SciError(17);
 			return 0;
 		}
 	} 
@@ -189,7 +188,7 @@ static int asciiStrings(char *fname)
 		if (Err > 0) 
 		{
 			/* stacksize exceeded */
-			Error(17);
+			SciError(17);
 			return 0;
 		}
 		C2F(icopy)(&nbr_characters, istk(l), &one, istk(l + nbr_characters), &one);
