@@ -2,6 +2,7 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) INRIA - Allan CORNET
+ * Copyright (C) DIGITEO - Allan CORNET - 2009
  * 
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
@@ -15,14 +16,18 @@
 #ifndef __ISDIGIT_H__
 #define __ISDIGIT_H__
 
+#include <wchar.h>
+
 #include "BOOL.h"
 
 /**
 * array elements that are digit between 0 and 9
-* @param[in] a string
+* @param[in] a wide string
+* @param[out] size of returned array
 * @return BOOL array 
 */
-BOOL *IsDigit(char *input_string);
+
+BOOL *IsDigitW(wchar_t *input_string, int *sizeReturnedArray);
 
 #endif /* __ISDIGIT_H__ */
 /*--------------------------------------------------------------------------*/
