@@ -14,13 +14,13 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(sciaddfsubf)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_addf)(char *fname,unsigned long fname_len)
+int sci_addf(char *fname,unsigned long fname_len)
 {
 	C2F(sciaddfsubf)(fname,fname_len);
 	return 0;
 }
 /*--------------------------------------------------------------------------*/
-int C2F(sci_subf)(char *fname,unsigned long fname_len)
+int sci_subf(char *fname,unsigned long fname_len)
 {
 	C2F(sciaddfsubf)(fname,fname_len);
 	return 0;
