@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(scimulf)(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_mulf)(char *fname,unsigned long fname_len)
+int sci_mulf(char *fname,unsigned long fname_len)
 {
 	C2F(scimulf)(fname,fname_len);
 	return 0;
