@@ -20,20 +20,20 @@
 /*--------------------------------------------------------------------------*/
 TCLSCI_IMPEXP int gw_tclsci(void);
 /*--------------------------------------------------------------------------*/
-TCLSCI_IMPEXP int sci_TCL_DoOneEvent (char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_EvalFile(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_EvalStr(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_GetVar(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_SetVar(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_opentk(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_GetVersion(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_UnsetVar(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_ExistVar(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_UpVar(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_DeleteInterp(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_CreateSlave(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_ExistInterp(char *fname,unsigned long fname_len);
-TCLSCI_IMPEXP int sci_TCL_ExistArray(char *fname,unsigned long fname_len);
+int sci_TCL_DoOneEvent (char *fname,unsigned long fname_len);
+int sci_TCL_EvalFile(char *fname,unsigned long fname_len);
+int sci_TCL_EvalStr(char *fname,unsigned long fname_len);
+int sci_TCL_GetVar(char *fname,unsigned long fname_len);
+int sci_TCL_SetVar(char *fname,unsigned long fname_len);
+int sci_opentk(char *fname,unsigned long fname_len);
+int sci_TCL_GetVersion(char *fname,unsigned long fname_len);
+int sci_TCL_UnsetVar(char *fname,unsigned long fname_len);
+int sci_TCL_ExistVar(char *fname,unsigned long fname_len);
+int sci_TCL_UpVar(char *fname,unsigned long fname_len);
+int sci_TCL_DeleteInterp(char *fname,unsigned long fname_len);
+int sci_TCL_CreateSlave(char *fname,unsigned long fname_len);
+int sci_TCL_ExistInterp(char *fname,unsigned long fname_len);
+int sci_TCL_ExistArray(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
 #endif /*  __GW_TCLSCI__ */
 /*--------------------------------------------------------------------------*/
