@@ -124,8 +124,9 @@ static long ymd_to_scalar (unsigned year, unsigned month, unsigned day)
 {
     long scalaire;
     scalaire = day + months_to_days(month);
-    if ( month > 2 )
-    scalaire -= isBissextile(year) ? 1 : 2;
+    if ( month > 2 ) {
+        scalaire -= isBissextile(year) ? 1 : 2;
+    }
     year--;
     scalaire += years_to_days(year);
     return scalaire;
