@@ -25,18 +25,18 @@
 
 #include "machine.h"
 /**
- * TODO : comment
- * @param dt
- * @param ierr
+ * get current date
+ * @param[out] dt time_t struct  
+ * @param[out] ierr != 0 (fails)
  */
 void C2F(scigetdate) (time_t *dt, int *ierr);
 
 
 /**
- * TODO : comment
- * @param dt
- * @param w
+ * Convert date time_t to int matrix
+ * @param[in] dt time_t struct 
+ * @param[out] datematrix date int matrix
  */
-void C2F(convertdate) (time_t *dt, int w[]);
+void C2F(convertdate) (time_t *dt, int datematrix[]);
 
 #endif /* __GETDATE_H__ */
