@@ -38,7 +38,7 @@ int sci_istssession(char *fname,unsigned long l)
 	}  	
 
 	m1 = 1;n1 = 1;
-	CreateVarFromPtr(Rhs+1,MATRIX_OF_BOOLEAN_DATATYPE, &n1, &n1, &Status);
+	CreateVarFromPtr(Rhs+1,MATRIX_OF_BOOLEAN_DATATYPE, &m1, &n1, &Status);
 	LhsVar(1)=Rhs+1;
 
 	C2F(putlhsvar)();
