@@ -33,7 +33,7 @@ int sci_win64(char *fname,unsigned long l)
 #endif
 
 	m1 = 1;n1 = 1;
-	CreateVarFromPtr(Rhs+1,MATRIX_OF_BOOLEAN_DATATYPE, &n1, &n1, &Status);
+	CreateVarFromPtr(Rhs+1,MATRIX_OF_BOOLEAN_DATATYPE, &m1, &n1, &Status);
 	LhsVar(1)=Rhs+1;
 
 	C2F(putlhsvar)();
