@@ -14,6 +14,7 @@
 #ifndef __WINCONSOLE_H__
 #define __WINCONSOLE_H__
 /*--------------------------------------------------------------------------*/ 
+#include "dynlib_windows_tools.h"
 /*--------------------------------------------------------------------------*/ 
 /* Theses functions are used to manipulate console 'dos' added to GUI */
 /* only for windows */
@@ -22,29 +23,29 @@
 /**
 * hide scilex console
 */
-void HideScilex(void);
+WINDOWS_TOOLS_IMPEXP void HideScilex(void);
 
 /**
 * show scilex console
 */
-void ShowScilex(void);
+WINDOWS_TOOLS_IMPEXP void ShowScilex(void);
 
 /**
 * switch between hide and show
 */
-void SwitchConsole(void);
+WINDOWS_TOOLS_IMPEXP void SwitchConsole(void);
 
 /**
 * Get console state
 *@return state 0 hide , 1 show
 */
-int GetConsoleState(void);
+WINDOWS_TOOLS_IMPEXP int GetConsoleState(void);
 
 /**
 * Set console state
 * @param[in] 0 hide , 1 show
 */
-void SetConsoleState(int state);
+WINDOWS_TOOLS_IMPEXP void SetConsoleState(int state);
 
 #endif /* __WINCONSOLE_H__ */
 /*--------------------------------------------------------------------------*/ 
