@@ -14,10 +14,12 @@
 #ifndef __STARTUPMESSAGEBOX_H__
 #define __STARTUPMESSAGEBOX_H__
 
+#include "dynlib_scilab_windows.h"
+
 /**
 * Display startup message box
 */
-void StartupMessageBox(void);
+SCILAB_WINDOWS_IMPEXP void StartupMessageBox(void);
 
 #endif /* __STARTUPMESSAGEBOX_H__ */
 /*--------------------------------------------------------------------------*/
