@@ -14,24 +14,33 @@
 #include <stdio.h>
 #include <Windows.h>
 #include "winopen.h"
-#include "cluni0.h"
+#include "expandPathVariable.h"
 #include "Scierror.h"
 #include "PATH_MAX.h"
+#include "charEncoding.h"
+#include "MALLOC.h"
 /*--------------------------------------------------------------------------*/
 BOOL winopen(char *scilabfilename)
 {
 	BOOL bOK = FALSE;
-	char filename[PATH_MAX + FILENAME_MAX];
+	char *filename = NULL;
+	wchar_t *wcfilename = NULL;
 	int out_n = 0;
 	long int lout = 0;
 	HINSTANCE error = NULL;
 
-	lout = PATH_MAX + FILENAME_MAX;
-	C2F(cluni0)(scilabfilename, filename, &out_n,(int)strlen(scilabfilename),lout);
-	error = ShellExecute(NULL, "open", filename, NULL, NULL, SW_SHOWNORMAL);
-	if ( error <= (HINSTANCE)32) bOK = FALSE;
-	else bOK = TRUE;
-
+	filename = expandPathVariable(scilabfilename);
+	if (filename)
+	{
+		wcfilename = to_wide_string(filename);
+		FREE(filename); filename = NULL;
+		if (wcfilename)
+		{
+			error = ShellExecuteW(NULL, L"open", wcfilename, NULL, NULL, SW_SHOWNORMAL);
+			if ( error <= (HINSTANCE)32) bOK = FALSE;
+			else bOK = TRUE;
+		}
+	}
 	return bOK;
 }
 /*--------------------------------------------------------------------------*/
