@@ -8,10 +8,9 @@
 // are also available at    
 // http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 /*--------------------------------------------------------------------------*/ 
+#include "gw_windows_tools.h"
 #include "Scierror.h"
 /*--------------------------------------------------------------------------*/ 
-int gw_windows_tools(void);
-/*--------------------------------------------------------------------------*/ 
 int gw_windows_tools(void)
 {
 	Scierror(999,"Scilab windows_tools module not installed.\n");
