@@ -20,7 +20,6 @@ import org.scilab.modules.graph.ScilabGraph;
 import org.scilab.modules.graph.actions.base.DefaultAction;
 import org.scilab.modules.gui.menuitem.MenuItem;
 import org.scilab.modules.gui.pushbutton.PushButton;
-import org.scilab.modules.xcos.XcosTab;
 import org.scilab.modules.xcos.graph.XcosDiagram;
 import org.scilab.modules.xcos.utils.XcosMessages;
 
@@ -73,7 +72,6 @@ public final class SaveAsAction extends DefaultAction {
 	public void actionPerformed(ActionEvent e) {
 		if (((XcosDiagram) getGraph(null)).saveDiagramAs(null)) {
 			((XcosDiagram) getGraph(null)).setModified(false);
-			XcosTab.updateRecentOpenedFilesMenu(((XcosDiagram) getGraph(null)));
 		}
 		
 	}
