@@ -13,12 +13,15 @@
 
 package org.scilab.modules.xcos.block;
 
-import org.scilab.modules.hdf5.scilabTypes.ScilabString;
-import org.scilab.modules.hdf5.scilabTypes.ScilabType;
+import org.scilab.modules.types.ScilabString;
+import org.scilab.modules.types.ScilabType;
 
 /**
  * A {@link BasicBlock} which print getExprs()[0][0] as bloc value.
+ * 
+ * @deprecated prefer using "displayedLabel" = "%s" style property. 
  */
+@Deprecated
 public class PrintBlock extends BasicBlock {
 	private final String format;
 	
@@ -50,6 +53,7 @@ public class PrintBlock extends BasicBlock {
     /**
      * @param exprs new exprs
      */
+	@Override
     public void setExprs(ScilabType exprs) {
     	super.setExprs(exprs);
     	
