@@ -17,6 +17,7 @@ import java.awt.Color;
 import java.awt.event.ActionEvent;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Map.Entry;
 
 import javax.swing.JColorChooser;
 
@@ -36,7 +37,7 @@ public final class FilledColorAction extends VertexSelectionDependantAction {
 	/** Name of the action */
 	public static final String NAME = XcosMessages.FILL_COLOR;
 	/** Icon name of the action */
-	public static final String SMALL_ICON = "";
+	public static final String SMALL_ICON = "color-fill.png";
 	/** Mnemonic key of the action */
 	public static final int MNEMONIC_KEY = 0;
 	/** Accelerator key for the action */
@@ -83,10 +84,10 @@ public final class FilledColorAction extends VertexSelectionDependantAction {
 	// Getting the most present color
 	String color = "#FF0000";
 	int max = 0;
-	for (String key : colorStats.keySet()) {
-		int current = colorStats.get(key);
+	for (Entry<String, Integer> entry : colorStats.entrySet()) {
+		final int current = entry.getValue();
 		if (current > max) {
-			color = key;
+			color = entry.getKey();
 			max = current;
 		}
 	}
