@@ -35,6 +35,7 @@ import java.util.regex.Pattern;
 
 import javax.swing.JFileChooser;
 import javax.swing.JOptionPane;
+import javax.swing.filechooser.FileNameExtensionFilter;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerException;
 import javax.xml.transform.TransformerFactory;
@@ -47,6 +48,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.scilab.modules.action_binding.highlevel.ScilabInterpreterManagement;
 import org.scilab.modules.action_binding.highlevel.ScilabInterpreterManagement.InterpreterException;
+import org.scilab.modules.commons.xml.ScilabTransformerFactory;
 import org.scilab.modules.graph.ScilabGraph;
 import org.scilab.modules.graph.utils.ScilabGraphConstants;
 import org.scilab.modules.gui.bridge.filechooser.SwingScilabFileChooser;
@@ -58,7 +60,6 @@ import org.scilab.modules.gui.messagebox.ScilabModalDialog.AnswerOption;
 import org.scilab.modules.gui.messagebox.ScilabModalDialog.ButtonType;
 import org.scilab.modules.gui.messagebox.ScilabModalDialog.IconType;
 import org.scilab.modules.gui.tab.Tab;
-import org.scilab.modules.gui.utils.SciFileFilter;
 import org.scilab.modules.types.ScilabMList;
 import org.scilab.modules.xcos.Xcos;
 import org.scilab.modules.xcos.XcosTab;
@@ -540,6 +541,8 @@ public class XcosDiagram extends ScilabGraph {
 
 	setMultiplicities();
 	
+	setAutoOrigin(true);
+	
 	// Add a listener to track when model is changed
 	getModel().addListener(mxEvent.CHANGE, new ModelTracker());
 	
@@ -1630,6 +1633,18 @@ public class XcosDiagram extends ScilabGraph {
 	    final SwingScilabFileChooser fc = ((SwingScilabFileChooser) ScilabFileChooser.createFileChooser().getAsSimpleFileChooser());
 	    fc.setTitle(XcosMessages.SAVE_AS);
 	    fc.setUiDialogType(JFileChooser.SAVE_DIALOG);
+	    
+	    // Xcos files or anything are supported
+	    {
+			final XcosFileType defaultFileType = XcosFileType.getDefault();
+			final FileNameExtensionFilter xcosFilter = new FileNameExtensionFilter(
+					defaultFileType.getDescription(),
+					defaultFileType.getExtension());
+			fc.addChoosableFileFilter(xcosFilter);
+			fc.setAcceptAllFileFilterUsed(true);
+			fc.setFileFilter(xcosFilter);
+	    }
+	    
 	    fc.setMultipleSelection(false);
 	    if (getSavedFile() != null) {
 	    	fc.setSelectedFile(getSavedFile());
@@ -1640,20 +1655,13 @@ public class XcosDiagram extends ScilabGraph {
 	    	}
 	    }
 
-	    final SciFileFilter xcosFilter = new SciFileFilter("*.xcos", null, 0);
-	    final SciFileFilter allFilter = new SciFileFilter("*.*", null, 1);
-	    fc.addChoosableFileFilter(xcosFilter);
-	    fc.addChoosableFileFilter(allFilter);
-	    fc.setFileFilter(xcosFilter);
-
-	    fc.setAcceptAllFileFilterUsed(false);
-	    fc.displayAndWait();
-
-	    if (fc.getSelection() == null || fc.getSelection().length == 0 || fc.getSelection()[0].equals("")) {
-		info(XcosMessages.EMPTY_INFO);
-		return isSuccess;
+	    int status = fc.showSaveDialog(this.getAsComponent());
+	    if (status != JFileChooser.APPROVE_OPTION) {
+	    	info(XcosMessages.EMPTY_INFO);
+	    	return isSuccess;
 	    }
-	    writeFile = new File(fc.getSelection()[0]);
+	    
+	    writeFile = fc.getSelectedFile();
 	}
 	
 	/* Extension checks */
@@ -1690,7 +1698,7 @@ public class XcosDiagram extends ScilabGraph {
 	 */
 	private void save(final File file) throws TransformerException {
 		final XcosCodec codec = new XcosCodec();
-		final TransformerFactory tranFactory = TransformerFactory.newInstance();
+		final TransformerFactory tranFactory = ScilabTransformerFactory.newInstance();
 		final Transformer aTransformer = tranFactory.newTransformer();
 		
 		final DOMSource src = new DOMSource(codec.encode(this));
@@ -1706,7 +1714,7 @@ public class XcosDiagram extends ScilabGraph {
 	 */
 	private void load(final File file) throws TransformerException {
 		final XcosCodec codec = new XcosCodec();
-		final TransformerFactory tranFactory = TransformerFactory.newInstance();
+		final TransformerFactory tranFactory = ScilabTransformerFactory.newInstance();
 		final Transformer aTransformer = tranFactory.newTransformer();
 		
 		final StreamSource src = new StreamSource(file);
@@ -1844,41 +1852,46 @@ public class XcosDiagram extends ScilabGraph {
 
     /**
      * Read a diagram from an HDF5 file (ask for creation if the file does not exist) 
-     * @param diagramFileName file to open
+     * @param diagram file to open
+     * @return the diagram instance or null on error 
      */
-    public void openDiagramFromFile(final File diagramFileName) {
-	    info(XcosMessages.LOADING_DIAGRAM);
+	public XcosDiagram openDiagramFromFile(final File diagram) {
+		info(XcosMessages.LOADING_DIAGRAM);
 
-	    if (diagramFileName.exists()) {
-	    	transformAndLoadFile(diagramFileName, false);
-	    } else {
-		AnswerOption answer;
-		try {
-			answer = ScilabModalDialog.show(getParentTab(), String.format(
-				XcosMessages.FILE_DOESNT_EXIST, diagramFileName.getCanonicalFile()),
-				XcosMessages.XCOS, IconType.QUESTION_ICON,
-				ButtonType.YES_NO);
-		} catch (final IOException e) {
-			LOG.error(e);
-			answer = AnswerOption.YES_OPTION;
-		}
+		if (diagram.exists()) {
+			transformAndLoadFile(diagram, false);
+		} else {
+			AnswerOption answer;
+			try {
+				answer = ScilabModalDialog.show(getParentTab(), String.format(
+						XcosMessages.FILE_DOESNT_EXIST,
+						diagram.getCanonicalFile()), XcosMessages.XCOS,
+						IconType.QUESTION_ICON, ButtonType.YES_NO);
+			} catch (final IOException e) {
+				LOG.error(e);
+				answer = AnswerOption.YES_OPTION;
+			}
 
-		if (answer == AnswerOption.YES_OPTION) {
-		    try {
-			final FileWriter writer = new FileWriter(diagramFileName);
-			writer.write("");
-			writer.flush();
-			writer.close();
-			setSavedFile(diagramFileName);
-		    } catch (final IOException ioexc) {
-		    	LOG.error(ioexc);
-		    	JOptionPane.showMessageDialog(getAsComponent(), ioexc);
-		    }
+			if (answer == AnswerOption.YES_OPTION) {
+				try {
+					final FileWriter writer = new FileWriter(diagram);
+					writer.write("");
+					writer.flush();
+					writer.close();
+					setSavedFile(diagram);
+				} catch (final IOException ioexc) {
+					LOG.error(ioexc);
+					JOptionPane.showMessageDialog(getAsComponent(), ioexc);
+				}
+			} else {
+				return null;
+			}
 		}
-	    }
-	    info(XcosMessages.EMPTY_INFO);
-	    getUndoManager().clear();
-    }
+		info(XcosMessages.EMPTY_INFO);
+		getUndoManager().clear();
+
+		return this;
+	}
     
 
     /**
