@@ -14,21 +14,26 @@ package org.scilab.modules.xcos.io;
 
 import java.util.Map;
 
-import org.scilab.modules.graph.io.ScilabObjectCodec;
+import org.scilab.modules.graph.utils.ScilabGraphConstants;
 import org.scilab.modules.graph.utils.StyleMap;
-import org.scilab.modules.xcos.utils.XcosConstants;
-import org.w3c.dom.NamedNodeMap;
-import org.w3c.dom.Node;
+import org.scilab.modules.xcos.link.commandcontrol.CommandControlLink;
+import org.scilab.modules.xcos.link.explicit.ExplicitLink;
+import org.scilab.modules.xcos.link.implicit.ImplicitLink;
 
-import com.mxgraph.io.mxCodec;
-import com.mxgraph.model.mxCell;
+import com.mxgraph.io.mxCellCodec;
+import com.mxgraph.io.mxCodecRegistry;
 
 /**
  * Codec for any xcos object
  */
-public class XcosObjectCodec extends ScilabObjectCodec {
+public class XcosObjectCodec extends mxCellCodec {
 	/**
-	 * Attribute name containing {@link mxCell} style.
+	 * Refs field for codecs
+	 */
+	protected static final String[] REFS = {"parent", "source", "target"};
+	
+	/**
+	 * Attribute name containing {@link com.mxgraph.model.mxCell} style.
 	 */
     protected static final String STYLE = "style";
     private static final String ROTATION = "rotation";
@@ -52,25 +57,16 @@ public class XcosObjectCodec extends ScilabObjectCodec {
 
     }
 
-	/**
-	 * Apply compatibility pattern to the decoded object
-	 * @param dec Codec that controls the decoding process.
-	 * @param node XML node to decode the object from.
-	 * @param obj Object decoded.
-	 * @return The Object transformed 
-	 * @see org.scilab.modules.xcos.io.XcosObjectCodec#afterDecode(com.mxgraph.io.mxCodec, org.w3c.dom.Node, java.lang.Object)
-	 */
-    public Object afterDecode(mxCodec dec, Node node, Object obj) {
-	if (node.getNodeName().equals("mxCell")) {
-	    NamedNodeMap attrs = node.getAttributes();
-	    for (int i = 0; i < attrs.getLength(); i++) {
-		Node attr = attrs.item(i);
-		if (attr.getNodeName().compareToIgnoreCase("id") == 0) {
-		    ((mxCell) obj).setId(attr.getNodeValue());
-		}
-	    }
-	}
-	return obj;
+    /**
+     * Register all the links codecs
+     */
+    public static void registerLinks() {
+    	XcosObjectCodec explicitlinkCodec = new XcosObjectCodec(new ExplicitLink() , null , null , null);
+    	mxCodecRegistry.register(explicitlinkCodec);
+    	XcosObjectCodec implicitlinkCodec = new XcosObjectCodec(new ImplicitLink() , null , null , null);
+    	mxCodecRegistry.register(implicitlinkCodec);
+    	XcosObjectCodec commandControllinkCodec = new XcosObjectCodec(new CommandControlLink() , null , null , null);
+    	mxCodecRegistry.register(commandControllinkCodec);
     }
 
     /**
@@ -101,12 +97,12 @@ public class XcosObjectCodec extends ScilabObjectCodec {
 
 		}
 
-		if (!style.containsKey(XcosConstants.STYLE_FLIP)) {
-			style.put(XcosConstants.STYLE_FLIP, Boolean.FALSE.toString());
+		if (!style.containsKey(ScilabGraphConstants.STYLE_FLIP)) {
+			style.put(ScilabGraphConstants.STYLE_FLIP, Boolean.FALSE.toString());
 		}
 
-		if (!style.containsKey(XcosConstants.STYLE_MIRROR)) {
-			style.put(XcosConstants.STYLE_MIRROR, Boolean.FALSE.toString());
+		if (!style.containsKey(ScilabGraphConstants.STYLE_MIRROR)) {
+			style.put(ScilabGraphConstants.STYLE_MIRROR, Boolean.FALSE.toString());
 		}
 	}
 }
