@@ -19,8 +19,9 @@ import org.scilab.modules.xcos.port.Orientation;
  * A control port acts as the execution tick for the block.
  * 
  * The block is executed only when a rising edge occurs on this port. As we are
- * writing 'edge', this port can only be connected to a {@link CommandPort}. The
- * port default orientation is the NORTH.
+ * writing 'edge', this port can only be connected to a 
+ * {@link org.scilab.modules.xcos.port.command.CommandPort}. The port default
+ * orientation is the NORTH.
  */
 public class ControlPort extends BasicPort {
 
@@ -30,12 +31,15 @@ public class ControlPort extends BasicPort {
     public ControlPort() {
 	super("ControlPort");
 	setOrientation(Orientation.NORTH);
+	
+	setDefaultValues();
     }
 
     /**
      * This port is untyped
      * @return always null
      */
+	@Override
     public Type getType() {
 	return null;
     }
